import pickle

slangdict = {
    "*4u": "Kiss for you",
    "*67": "unknown",
    "*eg*": "evil grin",
    "07734": "hello",
    "0day": "software illegally obtained before it was released",
    "0noe": "Oh No",
    "0vr": "over",
    "10q": "thank you",
    "10tacle": "tentacle",
    "10x": "thanks",
    "12b": "wannabe",
    "1337": "elite",
    "133t": "elite",
    "13itch": "bitch",
    "143": "I love you",
    "187": "murder",
    "1ab": "wannabe",
    "1daful": "wonderful",
    "1dering": "wondering",
    "1nce": "once",
    "1sec": "one second",
    # "2": "too",
    "2b": "to be",
    "2b4u": "too bad for you",
    "2bad4u2": "too bad for you too ",
    "2bh": "to be honest",
    "2da": "to the",
    "2dae": "today",
    "2day": "today",
    "2ditd": "today is the day",
    "2ez": "too easy",
    "2g2b4g": "To good to be forgotten",
    "2g2bt": "too good to be true",
    "2ge4": "Together",
    "2getha": "together ",
    "2gether": "together",
    "2gethr": "together",
    "2getr": "together",
    "2h2h": "too hot to handle",
    "2h4u": "too hot for you",
    "2k0": "2000",
    "2k1": "2001",
    "2k2": "2002",
    "2k3": "2003",
    "2k4": "2004",
    "2k5": "2005",
    "2k6": "2006",
    "2k7": "2007",
    "2k8": "2008",
    "2k9": "2009",
    "2l8": "too late",
    "2m": "tomorrow",
    "2m4u": "too much for you",
    "2ma": "Tomorrow",
    "2maro": "tomorrow",
    "2mmrw": "tomorrow",
    "2mo": "tomorrow",
    "2mora": "tomorrow",
    "2moro": "tomorrow",
    "2morow": "tomorrow",
    "2morro": "tomorrow",
    "2morrow": "tommorrow",
    "2moz": "tomorrow",
    "2mozz": "tomorrow",
    "2mro": "tomorrow",
    "2mrw": "tomorrow",
    "2mw": "tomorrow",
    "2mz": "tomorrow",
    "2night": "tonight",
    "2nite": "tonight",
    "2nyt": "tonight",
    "2o4s": "too old for sex",
    "2qt": "too cute",
    "2sday": "tuesday",
    "2tali": "totally",
    "2tm": "to the max",
    "2trd": "too tired",
    "2u2": "To you too",
    "301ing": "referring traffic to another site",
    "304": "hoe",
    "31337": "elite",
    "313373": "elite",
    "31ee7": "elite",
    "3arc": "Treyarch",
    "3q": "thank you",
    "3u": "thank you",
    "3vi1": "evil",
    "3y3 y4m": "I am",
    # "4": "for",
    "404": "Clueless",
    "42n8": "fortunate",
    "4311": "hell",
    "4col": "For crying out loud",
    "4e&e": "forever and ever",
    "4eva": "forever",
    "4ever": "forever",
    "4evr": "for ever",
    "4evs": "forever",
    "4fs": "for fuck's sake",
    "4g8": "forget",
    "4gai": "forget about it",
    "4geit": "forget it",
    "4get": "forget",
    "4getu": "forget you",
    "4give": "forgive",
    "4got": "forgot",
    "4gv": "forgive",
    "4head": "forehead",
    "4hoa": "four horsemen of the apocalypse",
    "4ker": "fucker",
    "4king": "fucking",
    "4lyf3": "for life",
    "4lyfe": "for life",
    "4m": "form",
    "4n": "Phone",
    "4q": "fuck you",
    "4r3al": "for real",
    "4rm": "from",
    "4sho": "for sure",
    "4tlog": "for the love of god",
    "4tw": "for the win",
    "4u": "for you",
    "4umb": "For You Maybe",
    "4us": "for us",
    "4ward": "forward",
    "4wd": "forward",
    "4yeo": "For Your Eyes Only",
    # " : ": "cop",
    "53x": "sex",
    "5h17": "shit",
    "5n": "fine",
    "5o": "police",
    "6flx": "sex movie",
    "6up": "cops in area",
    "6y": "sexy",
    "7734": "hell",
    "7uck": "fuck",
    "8008": "boob",
    "8008135": "boobies",
    "80085": "Boobs",
    "81tc#": "bitch",
    "9009l3": "Google",
    "911sc": "emergency let's stop chatting",
    "9t": "night",
    "<3": "love",
    "?u@": "Where are you?",
    "?up": "what's up?",
    "?^": "what's up?",
    "@": "at",
    "@$$": "ass",
    "@$$ #013": "ass hole",
    "@$$hole": "asshole",
    "@h": "asshole",
    "^5": "high five",
    "a$$": "ass",
    "a&f": "always and forever",
    "a'ight": "alright",
    "a.i.m.": "aol instant messanger",
    "a/l": "age and location",
    "a/m": "away message",
    "a/s/l": "age,sex,location",
    "a/s/l/p": "age/sex/location/picture",
    "a/s/l/r": "age, sex, location, race",
    "a1t": "anyone there",
    "a3": "anyplace, anywhere, anytime",
    "aaaaa": "American Assosciation Against Acronym Abuse",
    "aabf": "as a best friend",
    "aaf": "as a friend",
    "aak": "Alive and Kicking",
    "aamof": "as a matter of fact",
    "aatf": "always and totally forever",
    "aatw": "all around the world",
    "abd": "Already Been Done",
    "abend": "absent by enforced net deprivation",
    "abft": "About fucking Time",
    "aboot": "about",
    "abreev": "abbreviation",
    "absnt": "absent",
    "abt": "about",
    "abwt": "about",
    "acc": "account",
    "acct": "account",
    "acgaf": "Absolutely couldn't give a fuck",
    "ack": "acknowledged",
    "addy": "address",
    "adhd": "Attention Deficit Hyperactivity Disorder",
    "adl": "all day long",
    "admin": "administrator",
    "adn": "any day now",
    "aeap": "as early as possible",
    "af": "assface",
    "afaiaa": "As Far As I Am Aware",
    "afaic": "as far as I'm concerned",
    "afaicr": "As Far As I Can Remember",
    "afaics": "as far as I can see",
    "afaict": "as far as I can tell",
    "afaik": "as far as I know",
    "afair": "as far as I recall",
    "afaiu": "As far as I understand",
    "afc": "away from computer",
    "afcpmgo": "away from computer parents may go on",
    "afg": "away from game",
    "afk": "away from keyboard",
    "afkb": "away from keyboard",
    "agn": "again",
    "ah": "ass hole",
    "ahole": "asshole",
    "ai": "Artificial Intelligence",
    "aiadw": "ALL IN A DAYS WORK",
    "aiamu": "and I'm a monkey's uncle",
    "aicmfp": "and I claim my five pounds",
    "aight": "Alright",
    "aightz": "alright",
    "aiic": "as if I care",
    "aiid": "and if I did",
    "aiight": "all right",
    "aim": "AOL instant messanger",
    "ain't": "am not",
    "aite": "Alright",
    "aitr": "Adult in the room",
    "aiui": "as I understand it",
    "aiws": "as i was saying",
    "ajax": "Asynchronous Javascript and XML",
    "aka": "also known as",
    "akp": "Alexander King Project",
    "akpcep": "Alexander King Project Cultural Engineering Project",
    "alaytm": "as long as you tell me",
    "alol": "actually laughing out loud",
    "alot": "a lot",
    "alotbsol": "always look on the bright side of life",
    "alright": "all right",
    "alrite": "Alright",
    "alrt": "alright",
    "alryt": "alright",
    "ama": "ask me anything",
    "amf": "adios motherfucker",
    "amiic": "ask me if i care",
    "amiigaf": "ask me if i give a fuck",
    "aml": "All My Love",
    "amsp": "ask me something personal",
    "anim8": "animate",
    "anl": "all night long",
    "anlsx": "Anal Sex",
    "anon": "anonymous",
    "anuda": "another",
    "anw": "anyways",
    "anwwi": "alright now where was i",
    "any1": "Anyone",
    "anywaz": "anyways",
    "aob": "any other business",
    "aoc": "age of consent",
    "aoe": "Age Of Empires",
    "aon": "all or nothing",
    "aos": "adult over shoulder",
    "aota": "all of the above",
    "aoto": "Amen on that one",
    "aoys": "angel on your shoulder",
    "api": "application program interface",
    "apoc": "apocalypse",
    "apod": "Another Point Of Discussion",
    "app": "application",
    "appt": "appointment",
    "aprece8": "appreciate",
    "apreci8": "appreciate",
    "apu": "as per usual",
    "aqap": "as quick as possible",
    "ar": "are",
    "arnd": "around",
    "arse": "ass",
    "arsed": "bothered",
    "arvo": "afternoon",
    "asafp": "as soon as fucking possible",
    "asaik": "as soon as I know",
    "asap": "as soon as possible",
    "asarbambtaa": "All submissions are reviewed by a moderator before they are added.",
    "asbmaetp": "Acronyms should be memorable and easy to pronounce",
    "ase": "age, sex, ethnicity",
    "ashl": "asshole",
    "ashole": "asshole",
    "asic": "application specific integrated circuit",
    "asl": "age, sex, location",
    "aslo": "age sex location orientation",
    "aslop": "Age Sex Location Orientation Picture",
    "aslp": "age, sex, location, picture",
    "aslr": "age sex location race",
    "aslrp": "age, sex, location, race, picture",
    "asr": "age sex race",
    "asshle": "asshole",
    "atb": "all the best",
    "atfp": "answer the fucking phone",
    "atl": "atlanta",
    "atm": "at the moment",
    "ato": "against the odds",
    "atop": "at time of posting",
    "atp": "answer the phone",
    "atq": "answer the question",
    "atst": "At the same time",
    "attn": "attention",
    "attotp": "At The Time Of This Post",
    "atw": "All the way",
    "aty": "according to you",
    "audy": "Are you done yet?",
    "aufm": "are you fucking mental",
    "aufsm": "are you fucking shiting me",
    "aup": "acceptable use policy",
    "av7x": "avenged sevenfold",
    "avgn": "Angry Video Game Nerd",
    "avie": "Avatar",
    "avsb": "a very special boy",
    "avtr": "avatar",
    "avvie": "avatar",
    "avy": "Avatar",
    "awes": "awesome",
    "awk": "awkward",
    "awol": "absent without leave",
    "awsic": "and why should i care",
    "awsm": "awesome",
    "awsome": "awesome",
    "ayagob": "are you a girl or boy",
    "ayb": "All Your Base",
    "aybab2m": "all your base are belong 2 me",
    "aybab2u": "All your base are belong to us",
    "aybabtg": "All Your Base Are Belong To Google",
    "aybabtu": "all your base are belong to us",
    "ayc": "awaiting your comments",
    "ayd": "are you done",
    "aydy": "are you done yet",
    "ayec": "at your earliest convenience",
    "ayfk": "are you fucking kidding",
    "ayfkm": "are you fucking kidding me",
    "ayfr": "are you for real",
    "ayfs": "Are You fucking Serious",
    "ayk": "are you kidding",
    "aykm": "are you kidding me",
    "ayl": "are you listening",
    "aymf": "are you my friend",
    "ayok": "are you okay",
    "ays": "are you serious",
    "aysm": "are you shitting me?",
    "ayst": "are you still there",
    "ayt": "are you there",
    "ayte": "alright",
    "aytf": "are you there fucker",
    "ayty": "are you there yet",
    "ayw": "as you wish",
    "azhol": "asshole",
    "azn": "asian",
    "azz": "ass",
    "b&": "banned",
    "b'day": "birthday",
    "b-cuz": "because",
    "b-day": "birthday",
    "b.f.f.": "best friend forever",
    "b.s.": "bullshit",
    "b/c": "because",
    "b/cos": "because",
    "b/g": "background",
    "b/s/l": "Bisexual/Straight/Lesbian",
    "b/t": "between",
    "b/w": "between",
    "b00n": "new person",
    "b00t": "boot",
    "b0rked": "broken",
    "b1tch": "bitch",
    "b2b": "business to business",
    "b2u": "back to you",
    "b2w": "Back to work",
    "b3": "be",
    "b4": "before",
    "b4n": "bye for now",
    "b4u": "before you",
    "b8": "bait",
    "b82rez": "Batteries",
    "b8rez": "Batteries",
    "b@": "banned",
    "bab": "Big ass Boobs",
    "babi": "baby",
    "baf": "bring a friend",
    "baggkyko": "be a good girl, keep your knickers on",
    "bah": "I don't really care",
    "bai": "Bye",
    "bak": "back",
    "bakk": "back",
    "balz": "balls",
    "bamf": "bad ass mother fucker",
    "bamofo": "bitch ass mother fucker",
    "bau": "back at you",
    "bb": "bye bye",
    "bb4h": "bros before hoes",
    "bb4n": "Bye-bye for now",
    "bbbj": "Bare Back Blow Job",
    "bbe": "baby",
    "bbf": "best boy friend",
    "bbfn": "Bye Bye for now",
    "bbfs": "best boyfriends",
    "bbfu": "be back for you",
    "bbg": "baby girl",
    "bbi": "Baby",
    "bbiab": "be back in a bit",
    "bbiaf": "be back in a few",
    "bbialb": "Be back in a little bit",
    "bbiam": "be back in a minute",
    "bbias": "be back in a second",
    "bbiaw": "be back in a while",
    "bbifs": "be back in a few seconds",
    "bbilb": "be back in a little bit",
    "bbilfm": "be back in like five minutes",
    "bbim": "Be Back In Minute",
    "bbk": "be back, ok?",
    "bbl": "be back later",
    "bbl8a": "Be Back Later",
    "bblig": "Be back later...i guess",
    "bbm": "BlackBerry Messenger",
    "bbml": "be back much later",
    "bbn": "be back never",
    "bbol": "be back online later",
    "bbp": "Banned by parents",
    "bbq": "be back quick",
    "bbrs": "be back really soon",
    "bbs": "be back soon",
    "bbsts": "be back some time soon",
    "bbt": "be back tomorrow",
    "bbtn": "be back tonite",
    "bbvl": "Be Back Very Later",
    "bbw": "be back whenever",
    "bbwb": "best buddy with boobs",
    "bbwe": "be back whenever",
    "bbwl": "be back way later",
    "bby": "baby",
    "bbz": "babes",
    "bc": "because",
    "bch": "bitch",
    "bck": "back",
    "bcnu": "be seeing you",
    "bcnul8r": "be seeing you later",
    "bcoz": "Because",
    "bcurl8": "Because you're late.",
    "bcuz": "because",
    "bd": "birthday",
    "bday": "birthday",
    "bdfl": "Benevolent Dictator For Life",
    "be4": "before",
    "beatch": "bitch",
    "bebe": "baby",
    "becuse": "because",
    "becuz": "because",
    "beech": "bitch",
    "beeoch": "bitch",
    "beezy": "bitch",
    "beotch": "bitch",
    "besos": "kisses",
    "bestie": "best friend",
    "betch": "bitch",
    "betcha": "bet you",
    "bettr": "better",
    "bewb": "boob",
    "bewbs": "boobs",
    "bewbz": "boobs",
    "bewt": "boot",
    "beyatch": "bitch",
    "beyotch": "bitch",
    "bezzie": "best friend",
    "bf": "boyfriend",
    "bf's": "boyfriend's",
    "bf+gf": "boyfriend and girlfriend",
    "bf4e": "best friends for ever",
    "bf4eva": "Best Friends forever",
    "bf4l": "best friends for life",
    "bfam": "brother from another mother",
    "bfd": "big fucking deal",
    "bfe": "Bum fuck Egypt",
    "bff": "best friend forever",
    "bffa": "best friends for always",
    "bffaa": "Best Friends Forever And Always",
    "bffae": "Best Friends Forever And Ever",
    "bffaw": "best friends for a while",
    "bffe": "Best friends forever",
    "bffeae": "Best Friend For Ever And Ever",
    "bffene": "Best Friends For Ever And Ever",
    "bffl": "best friends for life",
    "bffn": "best friends for now",
    "bfftddup": "best friends forever till death do us part",
    "bfg": "big fucking gun",
    "bfh": "bitch from hell",
    "bfhd": "big fat hairy deal",
    "bfitww": "best friend in the whole world",
    "bfn": "bye for now",
    "bfs": "Boyfriends",
    "bft": "big fucking tits",
    "bg": "background",
    "bh": "bloody hell",
    "bhwu": "back home with you",
    "biab": "back in a bit",
    "biach": "bitch",
    "biaf": "Back In A Few",
    "biatch": "bitch",
    "bibi": "bye bye",
    "bibifn": "bye bye for now",
    "bicbw": "but I could be wrong",
    "bich": "bitch",
    "bigd": "big deal",
    "bii": "bye",
    "bilf": "brother i'd like to fuck",
    "bilu": "baby i love you",
    "bion": "Believe it or not.",
    "biotch": "bitch",
    "bioya": "blow it out your ass",
    "bish": "bitch",
    "bitd": "back in the day",
    "biw": "boss is watching",
    "biwm": "bisexual white male",
    "biz": "Business",
    "bizatch": "bitch",
    "bizi": "Busy",
    "biznatch": "bitch",
    "biznitch": "bitch",
    "bizzle": "bitch",
    "bj": "blowjob",
    "bk": "back",
    "bka": "better known as",
    "bl": "bad luck",
    "bleme": "blog meme",
    "bleve": "believe",
    "blg": "blog",
    "blh": "bored like hell",
    "bling-bling": "jewelry",
    "blj": "blowjob",
    "bljb": "Blowjob",
    "blk": "black",
    "blkm": "Black Male",
    "blnt": "Better Luck Next time",
    "blog": "web log",
    "blogger": "web logger",
    "blu": "blue",
    "bm": "Bite Me",
    "bm&y": "between you and me",
    "bm4l": "best mates for life",
    "bma": "best mates always",
    "bmay": "between me and you",
    "bmf": "be my friend",
    "bmfe": "best mates forever",
    "bmfl": "best mates for life",
    "bmha": "bite my hairy ass",
    "bml": "bless my life",
    "bmoc": "Big Man On Campus",
    "bmttveot": "best mates till the very end of time",
    "bmvp": "be my valentine please",
    "bn": "been",
    "bndm3ovr": "Bend me over",
    "bng": "being",
    "bnib": "Brand new in Box",
    "bnol": "be nice or leave",
    "bnr": "banner",
    "bo": "body odour",
    "boati": "Bend Over And Take It",
    "bobfoc": "Body of Baywatch, Face of Crimewatch",
    "bobw": "Best of Both Worlds",
    "boffum": "Both of them",
    "bofh": "bitched operator from hell",
    "bogo": "buy one get one",
    "bogof": "buy one get one free",
    "bogsatt": "bunch of guys sitting around the table",
    "bohic": "Bend over here it comes",
    "bohica": "bend over, here it comes again",
    "boi": "boy",
    "bol": "Barking Out Loud",
    "bonr": "boner",
    "boomm": "bored out of my mind",
    "bord": "bored",
    "bos": "boss over shoulder",
    "botoh": "but on the other hand",
    "bout": "about",
    "bovered": "bothered",
    "bowt": "about",
    "boxor": "box",
    "bpot": "big pair of tits",
    "br": "bathroom",
    "brb": "be right back",
    "brbbrb": "br right back bath room break",
    "brbf": "Be Right Back fucker",
    "brbg2p": "be right back, got to pee",
    "brbigtp": "be right back, i got to pee.",
    "brbl": "be right back later",
    "brbmf": "be right back mother fucker",
    "brbn2gbr": "Be right back, I need to go to the bathroom",
    "brbs": "be right back soon",
    "brbts": "be right back taking shit",
    "brd": "bored",
    "brfb": "be right fucking back",
    "brgds": "best regards",
    "brh": "be right here",
    "bro": "brother",
    "bros": "brothers",
    "broseph": "brother",
    "brover": "Brother",
    "brt": "be right there",
    "bruh": "brother",
    "bruhh": "Brother",
    "bruv": "brother",
    "bruva": "brother",
    "bruz": "brothers",
    "bs": "bullshit",
    "bsmfh": "bitched System Manager From Hell",
    "bsod": "blue screen of death",
    "bsomn": "blowing stuff out my nose",
    "bstfu": "bitch shut the fuck up",
    "bstrd": "bitched",
    "bsx": "bisexual",
    "bsxc": "be sexy",
    "bt": "bit torrent",
    "btb": "by the by",
    "btch": "bitch",
    "btcn": "Better than Chuck Norris",
    "btd": "bored to death",
    "btdt": "been there done that",
    "btdtgtts": "Been there, done that, got the T-shirt",
    "btfl": "beautiful",
    "btfo": "back the fuck off",
    "btfw": "by the fucking way",
    "btias": "Be there in a second",
    "btm": "bottom",
    "btr": "better",
    "bts": "be there soon",
    "btsoom": "Beats The shit Out Of Me",
    "bttt": "been there, tried that",
    "bttyl": "be talking to you later",
    "btw": "by the way",
    "btwilu": "by the way i love you",
    "btwitiailwu": "by the way i think i am in love with you",
    "btwn": "between",
    "bty": "back to you",
    "bubar": "bushed up beyond all recognition",
    "bubi": "bye",
    "budzecks": "butt sex",
    "buhbi": "Bye Bye",
    "bukket": "bucket",
    "bur": "pussy",
    "burma": "be undressed ready my angel",
    "buszay": "busy",
    "but6": "buttsex",
    "butsecks": "butt sex",
    "butterface": "every thing is hot but her face",
    "buwu": "breaking up with you",
    "bw3": "Buffalo Wild Wings",
    "bwim": "by which i mean",
    "bwoc": "Big Woman On Campus",
    "bwpwap": "back when Pluto was a planet",
    "bwt": "but when though",
    "byak": "blowing you a kiss",
    "byeas": "good-bye",
    "byes": "bye bye",
    "bykt": "But you knew that",
    "byob": "Bring your own Beer",
    "byoc": "bring our own computer",
    "byoh": "bring your own high",
    "byself": "by myself",
    "bytabm": "beat you to a bloody mess",
    "bytch": "bitch",
    "bz": "busy",
    "bzns": "buisness",
    "bzy": "busy",
    "bzzy": "busy",
    "c": "see",
    "c 2 c": "cam to cam (webcams)",
    "c&c": "Command and Conquer",
    "c'mon": "Come On",
    "c-p": "sleepy",
    "c.y.a": "cover your ass",
    "c/b": "comment back",
    "c/t": "can't talk",
    "c14n": "canonicalization",
    "c2": "come to",
    "c2c": "care to chat?",
    "c2tc": "cut to the chase",
    "c4ashg": "care for a shag",
    "c@": "cat",
    "cam": "camera",
    "cancer stick": "cigarette",
    "catwot": "complete and total waste of time",
    "cawk": "cock",
    "cayc": "call at your convenience",
    "cb": "come back",
    "cba": "can't be arsed",
    "cbb": "can't be bothered",
    "cbf": "cant be fucked",
    "cbfa": "can't be fucking arsed",
    "cbfed": "can't be fucked",
    "cbi": "can't believe it",
    "ccl": "Couldn't Care Less",
    "ccna": "Cisco Certified Network Associate",
    "cd9": "Code 9 (other people nearby)",
    "celly": "cell phone",
    "cex": "sex",
    "cexy": "sexy",
    "cfas": "care for a secret?",
    "cfid": "check for identification",
    "cfm": "come fuck me",
    "cg": "Congratulations",
    "cgad": "couldn't give a dicn",
    "cgaf": "couldn't give a fuck",
    "cgf": "cute guy friend",
    "ch@": "chat",
    "champs": "champions",
    "char": "character",
    "cheezburger": "cheeseburger",
    "chik": "chick",
    "chilax": "chill and relax in one word",
    "chillax": "chill and relax",
    "chillin": "relaxing",
    "chk": "check",
    "chohw": "Come Hell or high water",
    "chr": "character",
    "chronic": "marijuana",
    "chswm": "come have sex with me",
    "chswmrn": "come have sex with me right now",
    "chu": "you",
    "chut": "pussy",
    "cid": "consider it done",
    "cig": "cigarette",
    "cigs": "cigarettes",
    "cihswu": "can i have sex with you",
    "cihyn": "can i have your number",
    "cilf": "child i'd like to fuck",
    "cing": "seeing",
    "cis": "computer information science",
    "ciwwaf": "cute is what we aim for",
    "cless": "clanless",
    "clm": "Cool Like Me",
    "clt": "Cool Like That",
    "cluebie": "clueless newbie",
    "cm": "call me",
    "cma": "Cover My ass",
    "cmao": "Crying My ass Off",
    "cmar": "cry me a river",
    "cmb": "comment me back",
    "cmbo": "combo",
    "cmcp": "call my cell phone",
    "cmeo": "crying my eyes out",
    "cmh": "Call My House",
    "cmiiw": "correct me if I'm wrong",
    "cmitm": "Call me in the morning",
    "cml": "call me later",
    "cml8r": "call me later",
    "cmliuw2": "call me later if you want to",
    "cmomc": "call me on my cell",
    "cmon": "Come on",
    "cmplcdd": "complicated",
    "cmplte": "complete",
    "cmptr": "computer",
    "cms": "content management system",
    "cmt": "comment",
    "cmw": "cutting my wrists",
    "cn": "can",
    "cnc": "Command and Conquer",
    "cnt": "can't",
    "cob": "close of business",
    "cod": "Call of Duty",
    "cod4": "call of duty 4",
    "cod5": "call of duty 5",
    "code 29": "moderator is watching",
    "code 8": "parents are watching",
    "code 9": "Parents are watching",
    "code9": "other people near by ",
    "cof": "Crying on the floor",
    "coiwta": "come on i wont tell anyone",
    "col": "crying out loud",
    "comin'": "coming",
    "comnt": "comment",
    "comp": "Computer",
    "compy": "computer",
    "congrats": "congratulations",
    "contrib": "contribution",
    "contribs": "contributions",
    "convo": "conversation",
    "coo": "cool",
    "cood": "could",
    "copyvio": "copyright violation",
    "cos": "because",
    "cotf": "crying on the floor",
    "cotm": "check out this myspace",
    "cowboy choker": "cigarette",
    "coz": "because",
    "cp": "child porn",
    "cpl": "Cyber Athlete Professional League",
    "cpm": "cost per 1000 impressions",
    "cptn": "captain",
    "cpu": "computer",
    "cpy": "copy",
    "cr": "Can't remember",
    "cr8": "crate",
    "crakalakin": "happening",
    "crazn": "crazy asian",
    "cre8or": "creator",
    "crm": "customer relationship management",
    "crp": "crap",
    "crs": "can't remember shit",
    "crunk": "combination of crazy and drunk",
    "crzy": "crazy",
    "cs": "Counter-Strike",
    "cs:s": "Counter-Strike: Source",
    "csi": "Crime Scene Investigation",
    "cskr": "cock sucker",
    "csl": "can't stop laughing",
    "ct": "can't talk",
    "ctc": "call the cell",
    "ctf": "capture the flag",
    "ctfd": "calm the fuck down",
    "ctfo": "chill the fuck out",
    "ctfu": "cracking the fuck up",
    "ctm": "chuckle to myself",
    "ctn": "can't talk now",
    "ctnbos": "can't talk now boss over shoulder",
    "ctncl": "Can't talk now call later",
    "ctpc": "cant talk parent(s) coming",
    "ctpos": "Can't Talk Parent Over Sholder",
    "ctrl": "control",
    "ctrn": "can't talk right now",
    "cts": "change the subject",
    "ctt": "change the topic",
    "cu": "goodbye",
    "cu2nit": "see you tonight",
    "cu46": "see you for sex",
    "cubi": "can you believe it",
    "cud": "could",
    "cuic": "see you in class",
    "cul": "see you later",
    "cul83r": "See you later",
    "cul8er": "see you later",
    "cul8r": "See You Later",
    "cul8tr": "see you later",
    "culd": "Could",
    "cunt": "vagina",
    "cuom": "see you on monday",
    "cuple": "couple",
    "curn": "calling you right now",
    "cut3": "cute",
    "cuwul": "catch up with you later",
    "cuz": "because",
    "cuzz": "Because",
    "cvq": "chucking very quietly",
    "cw2cu": "can`t wait to see you",
    "cwd": "comment when done",
    "cwm": "come with me",
    "cwmaos": "coffee with milk and one sugar",
    "cwot": "complete waste of time",
    "cwtgypo": "can't wait to get your panties off",
    "cwyl": "chat with ya later",
    "cya": "goodbye",
    "cyal": "see you later",
    "cyal8r": "see you later",
    "cyas": "see you soon",
    "cyb": "cyber",
    "cybl": "call you back later",
    "cybr": "cyber",
    "cybseckz": "cyber sex",
    "cye": "Close Your Eyes",
    "cyff": "change your font, fucker",
    "cyl": "see you later",
    "cyl,a": "see ya later, alligator",
    "cyl8": "see you later",
    "cyl8er": "see you later",
    "cylbd": "catch ya later baby doll",
    "cylor": "check your local orhtodox rabbi",
    "cym": "check your mail",
    "cyntott": "see you next time on Tech Today",
    "cyt": "see you tomorrow",
    "cyu": "see you",
    "c|n>k": "coffee through nose into keyboard",
    "d&c": "divide and conquer",
    "d&df": "drug & disease free",
    "d.t.f": "down to fuck",
    "d.w": "don't worry",
    "d/c": "disconnected",
    "d/l": "download",
    "d/m": "Doesn't Matter",
    "d/w": "don't worry",
    "d00d": "dude",
    "d1ck": "dick",
    "d2": "Diablo 2",
    "d2m": "dead to me",
    "d2t": "drink to that",
    "d8": "date",
    "da": "the",
    "da2": "Dragon Age 2",
    "dadt": "Don't ask. Don't tell.",
    "dafs": "do a fucking search",
    "dah": "dumb as hell",
    "daii": "day",
    "damhik": "don't ask me how I know",
    "damhikijk": "Don't Ask Me How I Know - I Just Know",
    "damhikt": "don't ask me how I know this",
    "dass": "dumb ass",
    "dat": "that",
    "dats": "that's",
    "dawg": "Friend",
    "dayum": "dicn",
    "dayumm": "dicn",
    "db": "database",
    "db4l": "drinking buddy for life",
    "dbab": "don't be a bitch",
    "dbafwtt": "Don't Be A Fool Wrap The Tool",
    "dbag": "douchebag",
    "dbeyr": "don't believe everything you read",
    "dbg": "don't be gay",
    "dbh": "don't be hating",
    "dbi": "Don't Beg It",
    "dbm": "don't bother me",
    "dbz": "DragonBall Z",
    "dc": "don't care",
    "dc'd": "disconnected",
    "dctnry": "dictionary",
    "dcw": "Doing Class Work",
    "dd": "don't die",
    "ddf": "Drug and Disease Free",
    "ddg": "Drop Dead Gorgeous",
    "ddl": "direct download",
    "ddos": "Distributed Denial of Service",
    "ddr": "dance dance revolution",
    "deets": "details",
    "deez": "these",
    "def": "definitely",
    "defs": "definetly",
    "degmt": "Don't Even Give Me That",
    "dem": "them",
    "der": "there",
    "dernoe": "I don't know",
    "detai": "don't even think about it",
    "dewd": "Dude",
    "dey": "they",
    "df": "Dumb fuck",
    "dfc": "DON'T fuckING CARE",
    "dfo": "dumb fucking operator",
    "dftba": "don't forget to be awesome",
    "dftc": "down for the count",
    "dfu": "don't fuck up",
    "dfw": "down for whatever",
    "dfw/m": "Don't fuck with Me",
    "dfwm": "Don't fuck with Me",
    "dfwmt": "Don't fucking waste my time",
    "dg": "don't go",
    "dga": "don't go anywhere",
    "dgac": "don't give a crap",
    "dgaf": "don't give a fuck",
    "dgara": "don't give a rats ass",
    "dgas": "Don't give a shit",
    "dgms": "Don't get me started",
    "dgoai": "don't go on about it",
    "dgt": "don't go there",
    "dgypiab": "don't get your panties in a bunch",
    "dh": "dickhead",
    "dhac": "Don't have a clue",
    "dhcp": "Dynamic Host Configuration Protocol",
    "dhly": "does he like you",
    "dhv": "Demonstration of Higher Value",
    "diacf": "die in a car fire",
    "diaf": "die in a fire",
    "diah": "die in a hole",
    "dic": "do i care",
    "dick": "penis",
    "diez": "dies",
    "diff": "difference",
    "dih": "dick in hand",
    "dikhed": "dickhead",
    "diku": "do i know you",
    "diky": "Do I know you",
    "dil": "Daughter in law",
    "dilf": "dad i'd like to fuck",
    "dillic": "Do I look like I care",
    "dillifc": "do I look like I fucking care",
    "dilligad": "do I look like I give a dicn",
    "dilligaf": "do I look like I give a fuck",
    "dilligas": "do i look like i give a shit",
    "din": "didn't",
    "din't": "didn't",
    "dirl": "Die in real life",
    "dis": "this",
    "dit": "Details in Thread",
    "diy": "do it yourself",
    "dju": "did you",
    "dk": "don't know",
    "dkdc": "don't know, don't care",
    "dl": "download",
    "dlf": "dropping like flies",
    "dlibu": "Dont let it bother you",
    "dln": "don't look now",
    "dm": "deathmatch",
    "dmaf": "do me a favor",
    "dmba*": "dumbass",
    "dmi": "don't mention it",
    "dmn": "dicn",
    "dmu": "don't mess up",
    "dmwm": "don't mess with me",
    "dmy": "don't mess yourself",
    "dn": "don't know",
    "dnd": "Do Not Disturb",
    "dndp": "Do not double post",
    "dnimb": "dancing naked in my bra",
    "dno": "don't know",
    "dnrta": "did not read the article",
    "dnrtfa": "did not read the fucking article",
    "dns": "Domain Name System",
    "dnt": "don't",
    "dnw": "Do not want",
    "doa": "dead on arrival",
    "dob": "date of birth",
    "dod": "Day of Defeat",
    "dogg": "friend",
    "doin": "doing",
    "doin'": "doing",
    "don": "denial of normal",
    "doncha": "Don't you",
    "donno": "don't know",
    "dont": "don't",
    "dontcha": "don't you",
    "dood": "dude",
    "doodz": "dudes",
    "dos": "denial of service",
    "dotc": "dancing on the ceiling",
    "doypov": "depends on your point of view",
    "dp": "display picture",
    "dpmo": "don't piss me off",
    "dprsd": "depressed",
    "dqmot": "don't quote me on this",
    "dqydj": "don't quit your day job",
    "dr00d": "druid",
    "drc": "don't really care",
    "drm": "dream",
    "drood": "druid",
    "dsided": "decided",
    "dsu": "don't screw up",
    "dt": "double team",
    "dta": "Don't Trust Anyone",
    "dtb": "don't text back",
    "dth": "down to hang",
    "dtl": "dicn the luck",
    "dtp": "Don't Type Please",
    "dtrt": "do the right thing",
    "dts": "Don't think so",
    "dttm": "don't talk to me",
    "dttml": "don't talk to me loser",
    "dttpou": "Don't tell the police on us",
    "dttriaa": "don't tell the RIAA",
    "du2h": "dicn you to hell",
    "ducy": "do you see why",
    "dugi": "do you get it?",
    "dugt": "did you get that?",
    "duk": "did you know",
    "dulm": "do you like me",
    "dum": "dumb",
    "dun": "don't",
    "dunna": "i don't know",
    "dunno": "I don't know",
    "duno": "don't know",
    "dupe": "duplicate",
    "dutma": "don't you text me again",
    "dvda": "double vaginal, double anal",
    "dw": "don't worry",
    "dwai": "don't worry about it",
    "dwb": "Driving while black",
    "dwbh": "don't worry, be happy",
    "dwbi": "Don't worry about it.",
    "dwi": "deal with it",
    "dwioyot": "Deal With It On Your Own Time",
    "dwmt": "don't waste my time",
    "dwn": "down",
    "dwt": "don't wanna talk",
    "dwy": "don't wet yourself",
    "dy2h": "dicn you to hell",
    "dya": "Do you",
    "dyac": "dicn you auto correct",
    "dycotfc": "do you cyber on the first chat",
    "dyec": "Don't You Ever Care",
    "dygtp": "did you get the picture",
    "dyk": "did you know",
    "dylh": "do you like him",
    "dylm": "do you love me",
    "dylos": "do you like oral sex",
    "dym": "Do you mind",
    "dynk": "do you not know",
    "dynm": "do you know me",
    "dyt": "Don't you think",
    "dyth": "dicn You To Hell",
    "dyw": "don't you worry",
    "dyw2gwm": "do you want to go with me",
    "dywtmusw": "do you want to meet up some where",
    "e-ok": "Electronically OK",
    "e.g.": "example",
    "e4u2s": "easy for you to say",
    "eabod": "eat a bag of dicks",
    "ead": "eat a dick",
    "ebitda": "earnings before interest, taxes, depreciation and amortization",
    "ecf": "error carried forward",
    "edumacation": "education",
    "eedyat": "idiot",
    "eejit": "idiot",
    "ef": "fuck",
    "ef-ing": "fucking",
    "efct": "effect",
    "effed": "fucked",
    "efffl": "extra friendly friends for life",
    "effin": "fucking",
    "effing": "fucking",
    "eg": "evil grin",
    "ehlp": "help",
    "eil": "explode into laughter",
    "el!t": "elite",
    "eleo": "Extremely Low Earth Orbit",
    "ello": "hello",
    "elo": "hello",
    "em": "them",
    "emm": "email me",
    "emo": "emotional",
    "emp": "eat my pussy",
    "enat": "every now and then",
    "enit": "isn't it",
    "enof": "enough",
    "enuf": "enough",
    "enuff": "enough",
    "eob": "End of Business",
    "eoc": "end of conversation",
    "eod": "End of day",
    "eof": "end of file",
    "eom": "end of message",
    "eos": "end of story",
    "eot": "end of transmission",
    "eotw": "end of the world",
    "epa": "Emergency Parent Alert",
    "eq": "Everquest",
    "eq2": "Everquest2",
    "ere": "here",
    "errythin": "everything",
    "esad": "eat shit and die",
    "esadyffb": "eat shit and die you fat fucking bitched",
    "esbm": "Everyone sucks but me",
    "esc": "escape",
    "esl": "eat shit loser",
    "eta": "Estimated Time of Arrival",
    "etla": "extended three letter acronym",
    "etmda": "Explain it to my dumb ass",
    "etp": "eager to please",
    "eula": "end user license agreement",
    "ev1": "everyone",
    "eva": "ever",
    "evaa": "ever",
    "evar": "ever",
    "evercrack": "Everquest",
    "every1": "everyone",
    "evn": "even",
    "evr": "ever",
    "evry": "every",
    "evry1": "every one",
    "evrytin": "everything",
    "ex-bf": "Ex-Boy Friend",
    "ex-gf": "Ex-Girl Friend",
    "exp": "experience",
    "ey": "hey",
    "eyez": "eyes",
    "ez": "Easy",
    "ezi": "easy",
    "f u": "fuck you",
    "f#cking": "fucking",
    "f&e": "forever and ever",
    "f'n": "fucking",
    "f-ing": "fucking",
    "f.b.": "facebook",
    "f.m.l.": "fuck my life",
    "f.u.": "fuck you",
    "f/o": "fuck off",
    "f00k": "fuck.",
    "f2f": "face to face",
    "f2p": "free to play",
    "f2t": "Free to talk",
    "f4c3": "face",
    "f4eaa": "friends forever and always",
    "f4f": "female for female",
    "f4m": "female for male",
    "f8": "fate",
    "f9": "fine",
    "f@": "fat",
    "fa-q": "fuck you",
    "faa": "forever and always",
    "fab": "fabulous",
    "faggit": "faggot",
    "fah": "Funny as hell",
    "faic": "For All I Care",
    "fam": "family",
    "fankle": "area between foot and ankle",
    "fao": "for attention of",
    "fap": "masturbate",
    "fapping": "masterbating",
    "faq": "frequently asked question",
    "farg": "fuck",
    "fashizzle": "for sure",
    "fav": "Favorite",
    "fave": "favorite",
    "fawk": "fuck",
    "fbimcl": "Fall Back In My Chair Laughing",
    "fbk": "facebook",
    "fbtw": "Fine Be That Way",
    "fc": "fruit cake",
    "fcbk": "facebook",
    "fcfs": "first come first served",
    "fck": "fuck",
    "fckd": "fucked",
    "fckin": "fucking",
    "fcking": "fucking",
    "fckm3hdbayb": "fuck Me Hard Baby",
    "fcku": "fuck you",
    "fcol": "for crying out loud",
    "fcuk": "fuck",
    "fe": "fatal error",
    "feck": "fuck",
    "fer": "for",
    "ferr": "For",
    "ff": "friendly fire",
    "ffa": "free for all",
    "ffcl": "falling from chair laughing",
    "ffr": "for future reference",
    "ffs": "for fuck's sake",
    "fft": "food for thought",
    "ffxi": "Final Fantasy 11",
    "fg": "fucking gay",
    "fgi": "fucking google it",
    "fgs": "for God's sake",
    "fgssu": "For Gods sake shut up",
    "fgt": "faggot",
    "fi": "fuck it",
    "fi9": "fine",
    "fibijar": "fuck it buddy, I'm just a reserve",
    "fifo": "first in, first out",
    "fify": "Fixed It For You",
    "figjam": "fuck I'm good, just ask me",
    "figmo": "Fuck it - got my orders",
    "fiic": "fucked If I Care",
    "fiik": "fucked If I Know",
    "fimh": "forever in my heart",
    "fio": "figure it out",
    "fitb": "fill in the blank",
    "fiv": "five",
    "fk": "fuck",
    "fka": "formerly known as",
    "fkd": "fucked",
    "fker": "fucker",
    "fkin": "fucking",
    "fking": "fucking",
    "fkn": "fucking",
    "fku": "fuck you",
    "flamer": "angry poster",
    "flames": "angry comments",
    "flicks": "pictures",
    "floabt": "for lack of a better term",
    "fm": "fuck me",
    "fmah": "fuck my ass hole",
    "fmao": "freezing my ass of",
    "fmb": "fuck me bitch",
    "fmbb": "fuck Me Baby",
    "fmbo": "fuck my brains out",
    "fmfl": "fuck my fucking life",
    "fmflth": "fuck My fucking Life To Hell",
    "fmh": "fuck me hard",
    "fmhb": "fuck me hard bitch",
    "fmi": "for my information",
    "fmir": "family member in room",
    "fmita": "fuck me in the ass",
    "fml": "fuck my life",
    "fmltwia": "fuck me like the whore I am",
    "fmn": "fuck me now",
    "fmnb": "fuck me now bitch",
    "fmnkml": "fuck me now kiss me later",
    "fmph": "fuck my pussy hard",
    "fmq": "fuck me quick",
    "fmr": "fuck me runnig",
    "fmsh": "fuck me so hard",
    "fmth": "fuck me to hell",
    "fmuta": "fuck me up the ass",
    "fmutp": "fuck me up the pussy",
    "fn": "first name",
    "fnar": "For No Apparent Reason",
    "fnci": "fancy",
    "fnny": "funny",
    "fnpr": "for no particular reason",
    "fny": "funny",
    "fo": "fuck off",
    "fo shizzle": "for sure",
    "fo sho": "for sure",
    "foa": "fuck off asshole",
    "foad": "fuck off and die",
    "foaf": "friend of a friend",
    "foah": "fuck off asshole",
    "fob": "fresh off the boat",
    "focl": "Falling Off Chair Laughing.",
    "fofl": "fall on the floor laughing",
    "foia": "freedom of information act",
    "fol": "farting out loud",
    "folo": "Follow",
    "fomofo": "fuck off mother fucker",
    "fone": "phone",
    "foo": "fool",
    "foobar": "fucked up beyond all recognition",
    "foocl": "falls out of chair laughing",
    "fook": "fuck",
    "for sheeze": "for sure",
    "fos": "full of shit",
    "foshizzle": "for sure",
    "fosho": "for sure",
    "foss": "free, open source software",
    "fotcl": "fell off the chair laughing",
    "fotm": "Flavour of the month",
    "fouc": "fuck off you cunt ",
    "fov": "Field of View",
    "foyb": "fuck off you bitch",
    "fo`": "for",
    "fp": "first post",
    "fpmitap": "federal pound me in the ass prison",
    "fpos": "fucking piece of shit",
    "fps": "First Person Shooter",
    "frag": "kill",
    "fragged": "killed",
    "fren": "friend",
    "frens": "friends",
    "frgt": "forgot",
    "fri.": "Friday",
    "friggin": "freaking",
    "frk": "freak",
    "frm": "from",
    "frnd": "friend",
    "frnds": "friends",
    "fs": "For Sure",
    "fsho": "for sure",
    "fsm": "flying spaghetti monster",
    "fsob": "fucking son of a bitch",
    "fsod": "frosn screen of death",
    "fsr": "for some reason",
    "fst": "fast",
    "ft": "fuck THAT",
    "ft2t": "From time to time",
    "fta": "From The Article",
    "ftb": "fuck That bitch",
    "ftbfs": "Failed to build from source",
    "ftf": "face to face",
    "ftfa": "From The fucking Article",
    "ftfw": "For the fucking win!",
    "ftfy": "Fixed that for you",
    "ftio": "fun time is over",
    "ftk": "For the Kill",
    "ftl": "For The Lose",
    "ftlog": "for the love of god",
    "ftlt": "For the last time",
    "ftmfw": "for the mother fucking win",
    "ftmp": "For the most part",
    "ftp": "file transfer protocol",
    "ftr": "For The Record",
    "fts": "fuck that shit",
    "fttp": "for the time being",
    "ftw": "For the win!",
    "fu": "fuck you",
    "fua": "fuck you all",
    "fuah": "fuck you ass hole",
    "fub": "fuck you bitch",
    "fubah": "fucked up beyond all hope",
    "fubalm": "fucked up beyond all local maintenance",
    "fubar": "fucked up beyond all recognition",
    "fubb": "fucked up beyond belief",
    "fubh": "fucked up beyond hope",
    "fubohic": "fuck you Bend over here it comes",
    "fubr": "fucked Up Beyond Recognition",
    "fucken": "fucking",
    "fucktard": "fucking retard",
    "fuctard": "fucking retard",
    "fud": "fear, uncertainty and doubt",
    "fudh": "fuck you dick head",
    "fudie": "fuck you and die",
    "fugly": "fucking ugly",
    "fuh-q": "fuck you",
    "fuhget": "forget",
    "fuk": "fuck",
    "fukin": "fucking",
    "fukk": "fuck",
    "fukkin": "fucking",
    "fukn": "fucking",
    "fukr": "fucker",
    "fulla": "Full of",
    "fumfer": "fuck you mother fucker",
    "funee": "funny",
    "funner": "more fun",
    "funy": "funny",
    "fuq": "fuck you",
    "fus": "fuck yourself",
    "fut": "fuck You Too",
    "fuu": "fuck you up",
    "fux": "fuck",
    "fuxing": "fucking",
    "fuxor": "fucker",
    "fuxored": "fucked",
    "fvck": "fuck",
    "fwb": "Friends with Benefits",
    "fwd": "forward",
    "fwiw": "for what it's worth",
    "fwm": "Fine With Me",
    "fwob": "friends with occasional benefits",
    "fwp": "first world problems",
    "fxe": "foxy",
    "fxp": "file exchange protocol",
    "fy": "fuck you",
    "fya": "for your attention",
    "fyad": "fuck you and die",
    "fyah": "fuck you asshole",
    "fyb": "fuck you bitch",
    "fyc": "fuck your couch",
    "fye": "For Your Entertainment",
    "fyeo": "For your eyes only",
    "fyf": "fuck your face",
    "fyfi": "For Your fucking Information",
    "fyi": "for your information",
    "fyk": "for your knowledge",
    "fyl": "For your Love",
    "fym": "fuck your mom",
    "fyp": "fixed your post",
    "fyrb": "fuck you right back",
    "fytd": "fuck you to death",
    "*g*": "grin",
    "g'nite": "good night",
    "g/f": "girlfriend",
    "g/g": "got to go",
    "g0": "go",
    "g00g13": "Google",
    "g1": "good one",
    "g2": "go to",
    "g2/-/": "go to hell",
    "g2bg": "got to be going",
    "g2bl8": "going to be late",
    "g2cu": "glad to see you",
    "g2e": "got to eat",
    "g2g": "got to go",
    "g2g2tb": "got to go to the bathroom",
    "g2g2w": "got to go to work",
    "g2g4aw": "got to go for a while",
    "g2gb": "got to go bye",
    "g2gb2wn": "got to go back to work now",
    "g2ge": "got to go eat",
    "g2gn": "got to go now",
    "g2gp": "got to go pee",
    "g2gpc": "got 2 go parents coming",
    "g2gpp": "got to go pee pee",
    "g2gs": "got to go sorry",
    "g2h": "go to hell",
    "g2hb": "go to hell bitch",
    "g2k": "good to know",
    "g2p": "got to pee",
    "g2t2s": "got to talk to someone",
    "g3y": "gay",
    "g4u": "good for you",
    "g4y": "good for you",
    "g8": "gate",
    "g9": "good night",
    "g@y": "gay",
    "ga": "go ahead",
    "gaalma": "go away and leave me alone",
    "gaf": "good as fuck",
    "gafi": "get away from it",
    "gafl": "get a fucking life",
    "gafm": "Get away from me",
    "gagf": "go and get fucked",
    "gagp": "go and get pissed",
    "gah": "gay ass homo",
    "gai": "gay",
    "gaj": "get a job",
    "gal": "get a life",
    "gamez": "illegally obtained games",
    "gangsta": "gangster",
    "gank": "kill",
    "gaoep": "generally accepted office etiquette principles",
    "gaw": "grandparents are watching",
    "gawd": "god",
    "gb": "Go back",
    "gb2": "go back to",
    "gba": "game boy advance",
    "gbioua": "Go blow it out your ass",
    "gbnf": "Gone but not forgotten ",
    "gbtw": "go back to work",
    "gbu": "god bless you",
    "gby": "good bye",
    "gcad": "get cancer and die",
    "gcf": "Google Click Fraud",
    "gd": "good",
    "gd&r": "grins, ducks, and runs",
    "gd4u": "Good For You",
    "gday": "Good Day",
    "gdby": "good bye",
    "gded": "grounded",
    "gdgd": "good good",
    "gdi": "God dicn it",
    "gdiaf": "go die in a fire",
    "gdih": "Go die in hell",
    "gdilf": "Grandad I'd Like To fuck",
    "gdmfpos": "god dicn mother fucking piece of shit",
    "gdr": "grinning, ducking, running",
    "gemo": "gay emo",
    "getcha": "get you",
    "geto": "ghetto",
    "gewd": "good",
    "gey": "gay",
    "gf": "girlfriend",
    "gfad": "go fuck a duck",
    "gfadh": "go fuck a dead horse",
    "gfak": "go fly a kite",
    "gfam": "Go fuck A Monkey",
    "gfar2cu": "go find a rock to crawl under",
    "gfas": "go fuck a sheep",
    "gfd": "god fucking damnit",
    "gfe": "Girl Friend experience",
    "gfe2e": "grinning from ear to ear",
    "gfg": "good fucking game",
    "gfgi": "go fucking google it",
    "gfi": "good fucking idea",
    "gfj": "good fucking job",
    "gfl": "grounded for life",
    "gfo": "go fuck off",
    "gfu": "go fuck yourself",
    "gfurs": "go fuck yourself",
    "gfus": "go fuck yourself",
    "gfx": "graphics",
    "gfy": "good for you",
    "gfyd": "go fuck your dad",
    "gfym": "go fuck your mom",
    "gfys": "go fuck yourself",
    "gg": "good game",
    "gga": "good game all",
    "ggal": "go get a life",
    "ggf": "go get fucked",
    "ggg": "Go, go, go! ",
    "ggnore": "good game no rematch",
    "ggp": "gotta go pee",
    "ggpaw": "gotta go parents are watching",
    "ggs": "good games",
    "gh": "good half",
    "ghei": "Gay",
    "ghey": "gay",
    "gigig": "get it got it good",
    "gigo": "garbage in garbage out",
    "gilf": "Grandma I'd like to fuck",
    "gim": "google instant messanger",
    "gimme": "give me",
    "gimmie": "give me",
    "gir": "google it retard",
    "gis": "Google Image Search",
    "gitar": "guitar",
    "giv": "give",
    "giyf": "google is your friend",
    "gj": "good job",
    "gjial": "go jump in a lake",
    "gjp": "good job partner",
    "gjsu": "god just shut up",
    "gjt": "good job team",
    "gky": "Go kill yourself",
    "gkys": "Go kill yourself",
    "gl": "good luck",
    "gl hf": "good luck, have fun",
    "gl&hf": "good luck and have fun",
    "gla": "good luck all",
    "glbt": "Gay, lesbian, bisexual, transgenderd",
    "glf": "group looking for",
    "glhf": "good luck have fun",
    "glln": "Got Laid Last Night",
    "glnhf": "Good Luck and Have Fun",
    "glty": "Good luck this year",
    "glu": "girl like us",
    "glu2": "good luck to you too",
    "glux": "good luck",
    "glwt": "good luck with that",
    "gm": "good morning",
    "gma": "grandma",
    "gmab": "give me a break",
    "gmabj": "give me a blowjob",
    "gmafb": "give me a fucking break",
    "gmao": "Giggling my ass off",
    "gmfao": "Giggling My fucking ass Off",
    "gmilf": "grandmother i'd like to fuck",
    "gmod": "Global Moderator",
    "gmta": "great minds think alike",
    "gmtyt": "good morning to you too",
    "gmv": "Got my vote",
    "gmybs": "give me your best shot",
    "gn": "good night",
    "gn8": "good night",
    "gnasd": "good night and sweet dreams",
    "gndn": "Goes nowhere,does nothing",
    "gnfpwlbn": "good news for people who love bad news",
    "gng": "going",
    "gng2": "going to",
    "gngbng": "gang bang",
    "gnight": "good night",
    "gnite": "good night",
    "gnn": "get naked now",
    "gno": "going to do",
    "gnoc": "get naked on cam",
    "gnos": "get naked on screen",
    "gnr": "Guns n' roses",
    "gnrn": "get naked right now",
    "gnst": "goodnight sleep tight",
    "gnstdltbbb": "good night sleep tight don't let the bed bugs bite",
    "goc": "get on camera",
    "goi": "get over it ",
    "goia": "get over it already",
    "goin": "going",
    "gok": "God Only Knows",
    "gokid": "got observers - keep it decent",
    "gokw": "God Only Knows Why",
    "gol": "giggle out loud",
    "gomb": "get off my back",
    "goml": "get out of my life",
    "gona": "Gonna",
    "gonna": "going to",
    "good9": "goodnite",
    "gooh": "get out of here!",
    "goomh": "get out of my head",
    "gork": "God only really knows",
    "gosad": "go suck a dick",
    "gotc": "get on the computer",
    "gotcha": "got you",
    "gotta": "got to",
    "gow": "gears of war",
    "goya": "Get Off Your ass",
    "goyhh": "get off your high horse",
    "gp": "good point",
    "gpb": "gotta pee bad",
    "gpwm": "good point well made",
    "gpytfaht": "gladly pay you tuesday for a hamburger today",
    "gr8": "great",
    "gr8t": "great",
    "grats": "congratulations",
    "gratz": "congratulations",
    "grfx": "graphics",
    "grillz": "metal teeth",
    "grl": "girl",
    "grmbl": "grumble",
    "grog": "beer",
    "grrl": "Girl",
    "grtg": "Getting ready to go",
    "grvy": "groovy",
    "gsad": "go suck a dick",
    "gsave": "global struggle against violent extremists",
    "gsd": "getting shit done",
    "gsfg": "Go search fucking google",
    "gsi": "go suck it",
    "gsoh": "Good Sense of Humor",
    "gsp": "get some pussy",
    "gsta": "Gangster",
    "gt": "get",
    "gta": "Grand Theft Auto",
    "gtas": "go take a shit",
    "gtb": "Go To Bed",
    "gtf": "get the fuck",
    "gtfa": "Go The fuck Away",
    "gtfbtw": "get the fuck back to work",
    "gtfh": "go to fucking hell",
    "gtfo": "get the fuck out",
    "gtfoi": "get the fuck over it",
    "gtfon": "Get the fuck out noob",
    "gtfooh": "get the fuck out of here",
    "gtfoomf": "get the fuck out of my face",
    "gtfu": "grow the fuck up",
    "gtfuotb": "get the fuck up out this bitch",
    "gtg": "got to go",
    "gtgb": "got to go bye",
    "gtgbb": "got to go bye bye",
    "gtgfn": "got to go for now",
    "gtgmmiloms": "got to go my mum is looking over my shoulder",
    "gtgn": "got to go now",
    "gtgp": "got to go pee",
    "gtgpp": "got to go pee pee",
    "gtgtb": "got to go to bed",
    "gtgtpirio": "got to go the price is right is on",
    "gtgtwn": "Got to go to work now",
    "gth": "go to hell",
    "gtha": "go the hell away",
    "gthb": "go to hell bitch",
    "gthmf": "go to hell mothafucka",
    "gtho": "get the hell out",
    "gthu": "grow the heck up",
    "gthyfah": "go to hell you fucking asshole",
    "gtk": "good to know",
    "gtm": "giggling to myself",
    "gtn": "getting",
    "gtp": "Got to pee",
    "gtr": "Got to run",
    "gts": "going to school",
    "gtsy": "good to see you",
    "gttp": "get to the point",
    "gtty": "good talking to you",
    "gu": "grow up",
    "gu2i": "get used to it ",
    "gud": "good",
    "gudd": "good",
    "gui": "graphical user interface",
    "gurl": "girl",
    "gurlz": "girls",
    "guru": "expert",
    "gw": "good work",
    "gwijd": "guess what i just did",
    "gwm": "gay white male",
    "gwork": "good work",
    "gwrk": "good work",
    "gws": "get well soon",
    "gwytose": "go waste your time on someone else",
    "gy": "gay",
    "gyal": "girl",
    "gypo": "Get Your Penis Out",
    "roflmfao": "rolling on the floor laughing my fucking ass off",
    "h&k": "hugs and kisses",
    "h*r": "homestar runner",
    "h+k": "hugs and kisses",
    "h.o": "hold on",
    "h/e": "However",
    "h/mo": "homo",
    "h/o": "hold on",
    "h/u": "hold up",
    "h/w": "homework",
    "h2": "Halo 2",
    "h2gtb": "have to go to the bathroom",
    "h2o": "water",
    "h2sys": "hope to see you soon",
    "h3y": "hey",
    "h4kz0r5": "hackers",
    "h4x": "Hacks",
    "h4x0r": "hacker",
    "h4xor": "hacker",
    "h4xr": "hacker",
    "h4xrz": "hackers",
    "h4xx0rz": "hacker",
    "h4xxor": "hacker",
    "h8": "hate",
    "h80r": "hater",
    "h82sit": "hate to say it",
    "h83r": "hater",
    "h8ed": "hated",
    "h8er": "hater",
    "h8r": "hater",
    "h8red": "Hatred",
    "h8s": "hates",
    "h8t": "hate",
    "h8t0r": "hater",
    "h8t3r": "hater",
    "h8te": "hate",
    "h8tr": "hater",
    "h8u": "I Hate You",
    "h9": "Husband in Room",
    "habt": "how about this",
    "hafta": "have to",
    "hagd": "have a good day",
    "hagl": "have a great life",
    "hagn": "have a good night",
    "hago": "have a good one",
    "hags": "have a great summer",
    "hai": "hello",
    "hait": "hate",
    "hak": "here's a kiss",
    "hakas": "have a kick ass summer",
    "hammrd": "hammered",
    "han": "how about now",
    "hau": "How Are You",
    "hav": "have",
    "havnt": "haven't",
    "hawf": "Husband and Wife forever",
    "hawt": "hot",
    "hawtie": "hottie",
    "hax": "Hacks",
    "hax0r": "hacker",
    "hax0red": "hacked",
    "hax0rz": "Hackers",
    "haxer": "Hacker",
    "haxor": "hacker",
    "haxoring": "hacking",
    "haxors": "hackers",
    "haxorz": "hackers",
    "haxxor": "hacker",
    "haxxzor": "Hacker",
    "haxz0r": "Hacker",
    "haxzor": "hacker",
    "hayd": "how are you doing",
    "hb": "hurry back",
    "hb4b": "hoes before bros",
    "hbd": "happy birthday",
    "hbic": "head bitch in charge",
    "hbii": "how big is it",
    "hbu": "how about you",
    "hby": "how about you",
    "hc": "how come",
    "hcbt1": "he could be the one",
    "hcib": "how can it be",
    "hcihy": "how can I help you",
    "hdop": "Help Delete Online Predators",
    "hdu": "how dare you",
    "hdydi": "How do you do it",
    "hdydt": "how did you do that",
    "heh": "haha",
    "hella": "very",
    "heya": "hey",
    "heyt": "hate",
    "heyy": "hello",
    "heyya": "hello",
    "hf": "have fun",
    "hfn": "Hell fucking no",
    "hfs": "holy fucking shit!",
    "hfsbm": "holy fucking shit batman",
    "hfwt": "have fun with that",
    "hg": "HockeyGod",
    "hght": "height",
    "hhiad": "holy hole in a doughnut",
    "hhiadb": "Holy Hole in a Donut Batman",
    "hhok": "Ha Ha Only Kidding",
    "hhyb": "how have you been",
    "hi2u": "hello",
    "hi2u2": "hello to you too",
    "hiet": "height",
    "hiik": "Hell If I Know",
    "hijack": "start an off topic discussion",
    "hith": "how in the hell",
    "hiw": "husband is watching",
    "hiya": "hello ",
    "hiybbprqag": "copying somebody else's search results",
    "hj": "hand job",
    "hl": "Half-Life",
    "hl2": "Half-Life 2",
    "hla": "Hot lesbian action",
    "hlb": "horny little bitched",
    "hld": "hold",
    "hldn": "hold on",
    "hldon": "hold on",
    "hll": "Hell",
    "hlm": "he loves me",
    "hlo": "hello",
    "hlp": "help",
    "hly": "holy",
    "hlysht": "Holy shit",
    "hmb": "hold me back",
    "hmewrk": "homework",
    "hmfic": "head mother fucker in charge",
    "hml": "hate my life",
    "hmoj": "holy mother of jesus",
    "hmu": "Hit Me Up",
    "hmul": "Hit me up later",
    "hmus": "Hit me up sometime",
    "hmw": "homework",
    "hmwk": "homework",
    "hmwrk": "Homework",
    "hng": "horny net geek",
    "hngry": "hungry",
    "hnic": "head nigger in charge",
    "ho": "hold on",
    "hoas": "Hang on a second",
    "hoay": "how old are you",
    "hoh": "head of household",
    "hom": "home",
    "homey": "Friend",
    "homie": "good friend",
    "homo": "homosexual",
    "hoopty": "broke down automobile",
    "hott": "hot",
    "howdey": "hello",
    "howz": "hows",
    "hpb": "high ping bitched",
    "hpoa": "Hot Piece of ass",
    "hppy": "Happy",
    "hpy": "happy",
    "hpybdy": "happy birthday",
    "hr": "hour",
    "hre": "here",
    "hrny": "horny",
    "hrs": "hours",
    "hru": "how are you",
    "hrud": "how are you doing",
    "hs": "headshot",
    "hsd": "high school dropout",
    "hsik": "how should i know",
    "hsr": "homestar runner",
    "hss": "horse shit and splinters",
    "hswm": "Have Sex With me",
    "ht": "Heard Through",
    "htc": "hit the cell",
    "htf": "how the fuck",
    "htfu": "Hurry the fuck up",
    "hth": "hope that helps",
    "hthu": "Hurry the hell up",
    "htr": "hater",
    "http": "hyper text transfer protocol",
    "hu": "Hey you",
    "hubby": "husband",
    "hud": "Heads Up Display",
    "huggle": "hug and cuddle",
    "hugz": "hugs",
    "hun": "honey",
    "hv": "have",
    "hve": "have",
    "hvnt": "haven't",
    "hw": "homework",
    "hw/hw": "help me with homework ",
    "hwg": "here we go",
    "hwga": "here we go again",
    "hwik": "how would i know",
    "hwk": "homework",
    "hwmbo": "he who must be obeyed",
    "hwmnbn": "he who must not be named",
    "hwms": "hot wild monkey sex",
    "hwu": "hey what's up",
    "hwz": "how is",
    "hxc": "hardcore",
    "hy": "hell yeah",
    "hyb": "how you been",
    "hyg": "here you go",
    "hyk": "how you know",
    "i <3 u": "I love you",
    "i c": "i see",
    "i8": "alright",
    "i8u": "i hate you",
    "i<3 u": "i love you",
    "i<3u": "I love you",
    "iab": "I Am Bored",
    "iafh": "I Am fucking Hot",
    "iafi": "I am from India",
    "iag": "it's all good",
    "iah": "i am horny",
    "iai": "i am interested",
    "ianabs": "I am not a brain surgeon",
    "ianacl": "I am not a copyright lawyer",
    "ianal": "I am not a lawyer",
    "ianalb": "I am not a lawyer, but..",
    "ianars": "I am not a rocket scientist",
    "ians": "I am Not Sure",
    "ianyl": "I am not your lawyer",
    "iap": "I Am Pissed",
    "iasb": "i am so bored",
    "iaspfm": "i am sorry please forgive me",
    "iatb": "I am the best",
    "iateu": "i hate you",
    "iavb": "i am very bored",
    "iaw": "In Another Window",
    "iawtc": "I agree with this comment",
    "iawtp": "I agree with this post",
    "iawy": "I agree with you",
    "ib": "I'm back",
    "ibbl": "I'll be back later",
    "ibcd": "Idiot between chair & desk",
    "ibs": "Internet bitch Slap ",
    "ibt": "I'll be there",
    "ibtl": "In Before The Lock",
    "ibw": "I'll be waiting",
    "ic": "I see",
    "icb": "I can't believe",
    "icbi": "i can't believe it",
    "icbiwoop": "I chuckled, but it was out of pity.",
    "icbt": "i can't believe that",
    "icbu": "I can't believe you",
    "icbyst": "i cant believe you said that",
    "iccl": "I could care less",
    "icgup": "I can give you pleasure",
    "icic": "I See. I See",
    "icp": "insane clown posse",
    "icr": "I can't rememer",
    "icsrg": "I can still reach Google",
    "ictrn": "I can't talk right now",
    "icty": "i can't tell you ",
    "icu": "i see you",
    "icudk": "in case you didn't know",
    "icup": "i see you pee",
    "icw": "I care why?",
    "icwudt": "I see what you did there",
    "icwum": "I see what you mean",
    "icydk": "in csae you didn't know",
    "icydn": "in case you didn't know",
    "icymi": "in case you missed it",
    "id10t": "idiot",
    "idbtwdsat": "I don't believe they would do such a thing",
    "idby": "I Don't Believe You",
    "idc": "I don't care",
    "iddi": "I didn't do it",
    "idec": "I don't even care",
    "idek": "I don't even know",
    "idfc": "i don't fucking care",
    "idfk": "i don't fucking know",
    "idfts": "I don't fucking think so",
    "idgac": "i don't give a crap",
    "idgad": "I don't give a dicn",
    "idgaf": "i don't give a fuck",
    "idgaff": "I don't give a flying fuck",
    "idgafs": "I don't give a fucking shit",
    "idgara": "I don't give a rat's ass",
    "idgas": "i don't give a shit",
    "idgi": "I don't get it",
    "idjit": "idiot",
    "idk": "I don't know",
    "idkbibt": "I don't know but I've Been Told",
    "idke": "I don't know ethier",
    "idkh": "I don't know how",
    "idkh2s": "i don't know how to spell",
    "idkt": "I don't know that",
    "idkw": "I don't know why",
    "idkwiwdwu": "I don't know what I would do without you",
    "idkwts": "I don't know what to say",
    "idkwurta": "I don't know what you are talking about.",
    "idkwym": "I don't know what you mean",
    "idky": "I don't know you",
    "idkyb": "i don't know why but",
    "idkymb2": "I didn't know yoru mom blogs too",
    "idl": "I don't like",
    "idli": "I don't like it",
    "idlu": "i don't like you",
    "idly": "I don't like you",
    "idlyitw": "i don't like you in that way",
    "idm": "I don't mind",
    "idn": "i don't know",
    "idnk": "i don't know",
    "idno": "i do not know",
    "idntk": "i dont need to know",
    "idnwths": "i do not want to have sex",
    "idonno": "i do not know",
    "idop": "it depends on price",
    "idot": "idiot",
    "idr": "I don't remember",
    "idrc": "i don't really care",
    "idrfk": "I don't really fucking know",
    "idrgaf": "I don't really give a fuck",
    "idrgaff": "i don't really give a flying fuck",
    "idrk": "i don't really know",
    "idrts": "I don't really think so",
    "idsw": "i don't see why",
    "idtis": "I don't think I should",
    "idtkso": "i don't think so",
    "idts": "i don't think so",
    "idunno": "i do not know",
    "iduwym": "I don't understand what you mean.",
    "idw2": "I don't want to",
    "idw2n": "i don't want to know",
    "idwk": "I don't wanna know",
    "idwt": "i don't want to",
    "idwtg": "I don't want to go",
    "idyat": "idiot",
    "iebkac": "issue exists between keyboard and chair",
    "ietf": "internet engineering task force",
    "iff": "if and only if",
    "ifhu": "I fucking hate you",
    "ifhy": "i fucking hate you",
    "ifk": "I fucking know",
    "iflu": "i fucking love you",
    "ifthtb": "i find that hard to belive",
    "ifttt": "if this then that ",
    "ifwis": "I forgot what I said",
    "ig": "I guess",
    "ig2g": "I got to go",
    "ig5oi": "I got 5 on it ",
    "igahp": "I've got a huge penis",
    "igalboc": "I've got a lovely bunch of cocnuts",
    "igg": "i gotta go",
    "ight": "alright",
    "igkymfa": "I'm gonna kick your mother fucking ass",
    "igs": "I guess so",
    "igt": "I Got This",
    "igtg": "i've got to go",
    "igtgt": "I got to go tinkle",
    "igtkya": "im going to kick your ass",
    "igu": "i give up",
    "igyb": "I Got Your Back",
    "ih": "it happens",
    "ih2gp": "I have to go pee",
    "ih2p": "i'll have to pass",
    "ih8": "i hate",
    "ih8mls": "I hate my little sister ",
    "ih8p": "I hate parents",
    "ih8tu": "i hate you",
    "ih8u": "I hate you",
    "ih8usm": "i hate you so much",
    "ih8y": "I hate you",
    "ihac": "I have a customer",
    "ihat3u": "I hate you",
    "ihistr": "i hope i spelled that right",
    "ihiwydt": "I hate it when you do that",
    "ihml": "I hate my life",
    "ihmp": "i hate my parents",
    "ihnc": "i have no clue",
    "ihnfc": "I have no fucking clue",
    "ihni": "i have no idea",
    "iht": "I heard that",
    "ihtfp": "I hate this fucking place",
    "ihtgttbwijd": "I have to go to the bathroom, wait I just did.",
    "ihtp": "I Have To Poop",
    "ihtsm": "i hate this so much",
    "ihtutbr": "I have to use the bathroom",
    "ihu": "I hate you",
    "ihurg": "i hate your guts",
    "ihusb": "i hate you so bad ",
    "ihusfm": "i hate you so fucking much",
    "ihusm": "i hate you so much",
    "ihy": "i hate you",
    "ihya": "i hate you all",
    "ihysm": "I hate you so much",
    "ihysmrn": "i hate you so much right now",
    "iigh": "alright",
    "iight": "alright",
    "iiok": "is it okay",
    "iirc": "if I recall correctly",
    "iistgtbtipi": "If It Sounds Too Good To Be True It Probably Is",
    "iit": "is it tight",
    "iitywimwybmad": "if I tell you what it means will you buy me a drink",
    "iitywybmad": "if I tell you, will you buy me a drink?",
    "iiuc": "if I understand correctly",
    "iiw2": "is it web 2.0?",
    "iiwii": "it is what it is",
    "ij": "indide joke",
    "ijaf": "it's just a fact",
    "ijcomk": "i just came on my keyboard",
    "ijdk": "I just don't know",
    "ijdl": "I just died laughing",
    "ijeomk": "I just ejaculated on my keybord",
    "ijf": "i just farted",
    "ijgl": "I just got laid",
    "ijit": "idiot",
    "ijk": "I'm Just kidding",
    "ijp": "Internet job posting",
    "ijpmp": "I just peed my pants",
    "ijpms": "I just pissed myself",
    "ijr": "i just remembered",
    "ijsabomomcibstg": "I just saved a bunch of money on my car insurance by switching to geico",
    "ik": "i know",
    "iki": "i know it",
    "ikm": "I know man",
    "ikr": "I know really",
    "ikt": "i knew that",
    "ikwud": "I know what you did",
    "ikwum": "I know what you meant",
    "ikwyl": "I know where you live",
    "ikwym": "i know what you mean",
    "ilbbaicnl": "I like big butts and I can not lie",
    "ilbcnu": "i'll be seeing you",
    "ilcul8r": "I'll see you later",
    "ilhsm": "i love him/her so much",
    "ili": "i love it",
    "ilk2fku": "I would like to fuck you",
    "ilml": "I Love My Life",
    "ilms": "I love my self",
    "ilotibinlirl": "I'm laughing on the internet, but I'm not laughing in real life",
    "ilshipmp": "I laughed so hard I peed my pants",
    "iltf": "i love to fuck",
    "ilu": "I love you",
    "ilu2": "I love you too",
    "iluaaf": "i love you as a friend",
    "ilulafklc": "I love you like a fat kid loves cake.",
    "ilum": "i love you more",
    "ilusfm": "I love you so fucking much",
    "ilusm": "I love you So much",
    "iluvm": "I Love You Very Much",
    "iluvu": "i love you",
    "iluvya": "i love you",
    "iluwamh": "i love you with all my heart",
    "ilvu": "i love you",
    "ily": "i love you",
    "ily2": "i love you too",
    "ily4e": "i love you forever",
    "ily4ev": "i love you forever",
    "ilyaas": "I Love You As A Sister",
    "ilyal": "I like you a lot",
    "ilyb": "i love you bitch",
    "ilybby": "i love you baby",
    "ilybtid": "I Love You But Then I Don't",
    "ilyf": "I'll Love You Forever",
    "ilygsm": "i love you guys so much",
    "ilykthnxbai": "i love you k thanks bye",
    "ilyl": "i love you loads",
    "ilylab": "I love you like a brother",
    "ilylabf": "I love you like a best friend",
    "ilylafklc": "i love you like a fat kid loves cake",
    "ilylas": "i love you like a sister",
    "ilylc": "i love you like crazy",
    "ilym": "i love you more",
    "ilymtyk": "i love you more than you know",
    "ilymtylm": "i love you more than you love me",
    "ilysfm": "i love you so fucking much",
    "ilysfmb": "i love you so fucking much baby",
    "ilysm": "i love you so much",
    "ilysmih": "i love you so much it hurts",
    "ilysmm": "i love you so much more",
    "ilysmydek": "I Love You So Much You Don't Even Know",
    "ilysvm": "i love you so very much",
    "ilyvm": "i love you very much",
    "ilywamh": "I love you with all my heart",
    "im": "Instant Message",
    "im'd": "instant messaged",
    "im26c4u": "I am too sexy for you",
    "ima": "I am a",
    "imao": "in my arrogant opinion",
    "imb": "I am back",
    "imcdo": "in my conceited dogmatic opinion",
    "imed": "instant messaged",
    "imfao": "In My fucking Arrogant Opinion",
    "imfo": "in my fucking opinion",
    "imh": "I am here",
    "imhbco": "In my humble but correct opinion",
    "imhe": "in my humble experience",
    "imho": "in my humble opinion",
    "imm": "instant message me",
    "imma": "I'm going to",
    "imnerho": "In my not even remotely humble opinion",
    "imnl": "I'm not laughing",
    "imnshmfo": "In My Not So Humble Mother fucking Opinion",
    "imnsho": "in my not so humble opinion",
    "imo": "in my opinion",
    "imoo": "in my own opinion",
    "impo": "In My Personal Opinion",
    "impov": "in my point of view",
    "imsb": "i am so bored",
    "imsry": "I am sorry",
    "imtaw": "it may take a while",
    "imts": "I meant to say",
    "imu": "i miss you ",
    "imusm": "I miss you so much",
    "imvho": "in my very humble opinion",
    "imwtk": "Inquiring minds want to know",
    "imy": "I miss you",
    "imy2": "i miss you to",
    "imya": "i miss you already",
    "imysfm": "i miss you so fucking much",
    "in2": "into",
    "inb4": "in before",
    "inbd": "it's no big deal",
    "incld": "include",
    "incrse": "increase",
    "ind2p": "I need to pee",
    "indie": "independent",
    "inef": "it's not even funny",
    "inet": "internet",
    "inh": "I need help",
    "inho": "in my honest opinion",
    "inhwh": "I need homework help",
    "init": "isn't it",
    "inmp": "it's not my problem",
    "innit": "isn't it",
    "ino": "I know",
    "instagib": "instant kill",
    "instakill": "instant kill",
    "intarwebs": "internet",
    "intel": "intelligence",
    "interweb": "internet",
    "intpftpotm": "I nominate this post for the post of the month",
    "inttwmf": "I am Not Typing This With My Fingers",
    "invu": "I envy you",
    "ioh": "I'm out of here",
    "iois": "Indicators of Interest",
    "iokiya": "it's ok if you are",
    "ionno": "I don't know",
    "iono": "I don't know",
    "iotd": "image of the day",
    "iou": "i owe you",
    "iow": "in other words",
    "ioya": "I'd Own Your ass",
    "ioyk": "if only you knew",
    "ip": "internet protocol",
    "irc": "internet relay chat",
    "irdc": "I really don't care",
    "irdgaf": "i really don't give a fuck",
    "irdk": "I really don't know",
    "irgtgbtw": "I've really got to get back to work",
    "irhtgttbr": "I really have to go to the bathroom",
    "irhy": "i really hate you",
    "irl": "in real life",
    "irly": "I really love you",
    "irt": "in reply to",
    "irtf": "I'll return the favor",
    "is2g": "i swear to god",
    "isb": "I'm so bored.",
    "isbya": "im sorry but you asked",
    "isd": "internet slang dictionary",
    "ise": "internal server error",
    "isfly": "i so fucking love you",
    "isg": "I speak geek",
    "ishii": "i see how it is",
    "isianmtu": "I swear I am not making this up",
    "isj": "inside joke",
    "iso": "In Search Of",
    "isp": "internet service provider",
    "iss": "im so sorry",
    "istr": "I seem to remember",
    "istwfn": "I stole this word from noslang.com",
    "iswydt": "i see what you did there",
    "ita": "I Totally Agree",
    "itb": "in the butt",
    "itc": "in that case",
    "itd": "in the dark",
    "ite": "alright",
    "itk": "in the know",
    "itn": "I think not",
    "itt": "in this thread",
    "ityltk": "I thought you'd like to know",
    "itz": "it's",
    "itzk": "it's ok",
    "iucmd": "if you catch my drift",
    "iukwim": "if you know what i mean",
    "iunno": "I don't know",
    "iuno": "i dunno",
    "ive": "i have",
    "iw2f": "i want to fuck",
    "iw2fu": "i want to fuck you",
    "iw2mu": "I want to meet you",
    "iwaa": "It was an accident",
    "iwbrbl@r": "I will be right back later",
    "iwc": "In Which Case",
    "iwfusb": "i wanna fuck you so bad",
    "iwfy": "I want to fuck you",
    "iwfybo": "i will fuck your brains out",
    "iwg": "it was good",
    "iwhi": "I would hit it",
    "iwhswu": "I want to have sex with you",
    "iwjk": "i was just kidding",
    "iwk": "I wouldn't know",
    "iwlu4e": "I will love you for ever",
    "iwmu": "i will miss you",
    "iwmy": "i will miss you",
    "iws": "i want sex",
    "iwsn": "i want sex now",
    "iwsul8r": "I will see you later",
    "iwtfu": "i want to fuck you",
    "iwtfy": "i want to fuck you",
    "iwthswy": "i want to have sex with you",
    "iwtly": "i want to love you",
    "iwu": "i want you",
    "iwuwh": "i wish you were here ",
    "iwy": "i want you",
    "iwyb": "I want your body",
    "iwyn": "I want you now",
    "iwythmb": "i want you to have my baby",
    "iyam": "if you ask me",
    "iyc": "if you can",
    "iyd": "In Your Dreams",
    "iydhantsdsaaa": "If you don't have anything nice to say don't say anything at all",
    "iydmma": "if you don't mind me asking",
    "iyf": "In your face",
    "iyflg": "If You're Feeling Less Generous",
    "iygm": "if you get me",
    "iykwim": "if you know what I mean",
    "iym": "I am your man",
    "iyo": "in your opinion",
    "iyq": "I like you",
    "iyss": "if you say so",
    "iyswim": "if you see what I mean",
    "iywt": "if you want to",
    "iz": "is",
    "j-c": "just chilling",
    "j/a": "Just Asking",
    "j/c": "just curious",
    "j/j": "just joking",
    "j/k": "just kidding",
    "j/o": "jackoff",
    "j/p": "just playing",
    "j/s": "just saying",
    "j/t": "just talking",
    "j/w": "just wondering",
    "j00": "you",
    "j00r": "your",
    "j2bs": "just to be sure",
    "j2c": "just too cute",
    "j2f": "just too funny",
    "j2luk": "just to let you know",
    "j2lyk": "just to let you know",
    "j4f": "just for fun",
    "j4g": "just for grins",
    "j4l": "just for laughs",
    "j4u": "just for you",
    "jalaudlm": "just as long as you don't leave me",
    "jas": "just a second",
    "jb": "jailbait",
    "jbu": "just between us",
    "jc": "just curious",
    "jcam": "just checking away message",
    "jcath": "Just chilling at the house",
    "jdfi": "Just fucking do it",
    "jebus": "Jesus",
    "jeomk": "Just ejaculated on my keyboard",
    "jf": "just fooling",
    "jfc": "Jesus fucking Christ",
    "jfdi": "Just fucking Do It!",
    "jff": "just for fun",
    "jfg": "just for giggles",
    "jfgi": "just fucking google it",
    "jfi": "just forget it",
    "jfj": "jump for joy",
    "jfk": "Just fucking kidding",
    "jfl": "just for laughs",
    "jflts": "just felt like typing something",
    "jfn": "just for now",
    "jfo": "just fuck off",
    "jfr": "Just for reference",
    "jftr": "just for the record",
    "jfu": "just for you",
    "jfwy": "just fucking with you",
    "jg2h": "just go to hell",
    "jgiyn": "Just google it you noob",
    "jgtfooh": "just get the fuck out of here",
    "jh": "Just hanging",
    "jhm": "just hold me",
    "jho": "just hanging out",
    "jic": "just in case",
    "jit": "just in time",
    "jizz": "semen",
    "jj": "just joking",
    "jj/k": "just joking",
    "jja": "just joking around",
    "jk": "just kidding",
    "jka": "just kidding around",
    "jking": "joking",
    "jkl": "just kidding loser",
    "jklol": "Just Kidding Laughing Out Loud",
    "jkn": "joking",
    "jks": "jokes",
    "jkz": "jokes",
    "jlma": "just leave me alone",
    "jlt": "just like that",
    "jm": "Just Messing",
    "jma": "just messing around",
    "jml": "just my luck",
    "jmo": "just my opinion",
    "jms": "just making sure",
    "jom": "just one minuite",
    "joo": "you",
    "jooc": "just out of curiosity",
    "jooce": "Juice",
    "joor": "your",
    "jp": "just playing",
    "js": "just saying",
    "jsa": "just stop already",
    "jsing": "just saying",
    "jst": "just",
    "jsuk": "just so you know",
    "jsun": "Just so you know",
    "jsut": "just",
    "jsyk": "Just so you know",
    "jsyn": "just so you know",
    "jtay": "just thinking about you",
    "jtbs": "Just To Be Sure",
    "jtc": "Join the club",
    "jtfo": "joke the fuck out",
    "jtluk": "just to let you know",
    "jtlyk": "just to let you know",
    "jtoi": "just thought of it",
    "jtol": "just thinking out loud",
    "jttsiowctw": "just testing to see if other websites copy this word",
    "jtty": "just to tell you",
    "jtumltk": "just thought you might like to know",
    "jtwii": "just the way it is.",
    "jtwiw": "just the way it was.",
    "jtyltk": "just thought you'd like to know",
    "jtysk": "just thought you should know",
    "jumping the couch": "acting strange",
    "jus": "just",
    "juss": "just",
    "juz": "just",
    "juzt": "just",
    "jw": "just wondering",
    "jw2k": "just wanted to know",
    "jwas": "just wait a second",
    "jwtlyk": "Just wanted to let you know",
    "jyfihp": "jam your finger in her pussy",
    "k": "ok",
    "k3wl": "cool",
    "ka": "Kick ass",
    "kafn": "kill all fucking noobs",
    "kah": "kisses and hugs",
    "kaw": "kick ass work",
    "kay": "okay",
    "kb": "KiloBite",
    "kcco": "keep calm chive on",
    "kek": "laughing out loud",
    "kewel": "cool",
    "kewl": "cool",
    "kfc": "kentucky fried chicken",
    "khitbash": "kick her in the box and shove her",
    "khuf": "know how you feel",
    "kia": "Killed In Action",
    "kib": "okay, im back",
    "kic": "keep it clean",
    "kicks": "sneakers",
    "kig": "keep it going",
    "kiled": "killed",
    "kinda": "kind of",
    "kir": "kid in room",
    "kis": "keep it simple",
    "kisa": "knight in shining armor",
    "kit": "keep in touch",
    "kitfo": "knock it the fuck off",
    "kitteh": "kitten",
    "kiu": "Keep it up",
    "kiwf": "Kill It With Fire",
    "kk": "ok",
    "kkk": "ku klux klan",
    "kkthnxbye": "okay thanks bye",
    "kky": "kinky",
    "kl": "cool",
    "km": "kiss me",
    "kma": "kiss my ass",
    "kmag": "kiss my ass goodbye",
    "kmao": "kick my ass off",
    "kmb": "kiss my butt",
    "kmfa": "kiss my fucking ass",
    "kmhba": "kiss my hairy big ass",
    "kml": "Killing Myself Laughing",
    "kmn": "kill me now",
    "kmp": "kill me please",
    "kmsl": "killing myself laughing",
    "kmswl": "killing myself with laughter",
    "knackered": "drunk",
    "knewb": "new player",
    "knn": "fuck your mother",
    "kno": "know",
    "knw": "know",
    "ko": "knock out",
    "kol": "kiss on lips",
    "koo": "cool",
    "kool": "cool",
    "kos": "kid over shoulder",
    "kotc": "kiss on the cheek",
    "kotl": "kiss on the lips",
    "kotor": "Knights of the old republic",
    "kots": "keep on talking shit",
    "kpc": "keeping parents clueless",
    "ks": "kill steal",
    "kss": "kiss",
    "kssd": "kissed",
    "kt": "keep talking",
    "ktc": "kill the cat",
    "ktfo": "knocked the fuck out",
    "kthanxbi": "Okay, thanks. Bye.",
    "kthnxbai": "Okay, thanks, bye",
    "kthnxbye": "Okay, thanks, bye",
    "kthx": "ok, thank you",
    "kthxbai": "ok thanks bye!",
    "kthxbi": "ok, thank you, goodbye",
    "kthxgb": "ok thanks goodbye",
    "kthxmn": "Ok Thanks Man",
    "kthz": "ok thanks",
    "ktnx": "Okay and Thanks",
    "kuhl": "cool",
    "kul": "cool",
    "kute": "cute",
    "kutgw": "Keep Up The good Work",
    "kuwl": "cool",
    "kwik": "quick",
    "kwim": "Know What I Mean",
    "kwis": "Know what I'm saying?",
    "kwit": "quit",
    "kwiz": "quiz",
    "kwl": "cool",
    "kwtsds": "Kiss where the sun don't shine",
    "kyag": "Kiss Your ass Goodbye",
    "kyfag": "kiss your fucking ass goodbye",
    "kyfc": "keep your fingers crossed",
    "kyko": "keep your knickers on",
    "kys": "kill yourself",
    "l0lz": "laugh out loud",
    "l2": "learn to",
    "l2m": "listening to music",
    "l2ms": "laughing to myself",
    "l2p": "learn to play",
    "l2r": "Learn to read",
    "l337": "elite",
    "l33t": "elite",
    "l4m3rz": "lamers",
    "l8": "late",
    "l84skool": "late for school",
    "l8a": "later",
    "l8er": "later",
    "l8ers": "Later",
    "l8r": "see you later",
    "l8rs": "laters",
    "l8rz": "later",
    "l8s": "later",
    "l8t": "later",
    "l8ta": "later",
    "l8ter": "later",
    "l8tr": "later",
    "l@u": "laughing at you",
    "laff": "laugh",
    "lafs": "love at first sight",
    "lak": "love and kisses",
    "lal": "laughing a little",
    "lalol": "lots and lots of laughs",
    "lam": "leave a message",
    "lamf": "like a motherfucker",
    "lan": "local area network",
    "lappy": "Laptop",
    "larp": "live action role-play",
    "lasb": "Lame ass Stupid bitch",
    "lat": "laugh at that",
    "lata": "later",
    "lates": "later",
    "latn": "laugh at the newbs",
    "latr": "Later",
    "latwttb": "laughing all the way to the bank",
    "lau": "laugh at you",
    "lawd": "lord",
    "lawl": "lauging out loud with a southern drawl",
    "lawl'd": "laughed out loud",
    "lawled": "laughed out loud",
    "lawls": "laughing out loud with a southern drawl",
    "lawlz": "laughing out loud with a southern drawl",
    "lazer": "laser",
    "lazor": "laser",
    "lbh": "let's be honest",
    "lbnr": "laughing but not really",
    "lbo": "laughing butt off ",
    "lbr": "little boy's room",
    "lbvs": "laughing but very serious",
    "lcsnpc": "low cost small notebook personal computer",
    "ldr": "Long-distance relationship",
    "lee7": "elite",
    "leet": "elite",
    "legit": "legitimate",
    "leik": "like",
    "leme": "let me",
    "lemme": "let me",
    "lesbo": "lesbian",
    "less than 3": "love",
    "less than three": "love",
    "lez": "Lesbian",
    "lezbean": "lesbian",
    "lezbo": "lesbian",
    "lezzzie": "lesbian",
    "lf": "looking for",
    "lf1m": "Looking for one more",
    "lf2m": "looking for 2 more",
    "lfg": "Looking for group",
    "lfl": "let's fuck later",
    "lfm": "looking for mate",
    "lfnar": "laughing for no aparent reason",
    "lfp": "looking for pussy",
    "lfr": "Laughing for real",
    "lgb": "lesbian/gay/bisexual",
    "lgbnaf": "lets get butt naked and fuck",
    "lgbtq": "Lesbien, Gay, Bisexual, Transgender and Queer.",
    "lgf": "little green footballs",
    "lggd": "let's go get drunk",
    "lgn": "link goes nowhere",
    "lgo": "life goes on",
    "lgot": "let's go out tonight",
    "lgr": "little girls room",
    "lgs": "let's go shopping!",
    "lhao": "laughing her ass off",
    "lhs": "lets have sex",
    "lhsrn": "let's have sex right now",
    "lic": "like i care",
    "liec": "like i even care",
    "liek": "like",
    "liekz": "likes",
    "lifo": "last in first out",
    "ligaff": "like I give a flying fuck",
    "ligafs": "like I give a flying shit",
    "ligas": "like I give a shit",
    "lih": "Laugh in head",
    "liita": "love is in the air",
    "lik": "like",
    "lil": "little",
    "lim": "Like it Matters",
    "limh": "laugh in my head",
    "liol": "laugh insanely out loud",
    "lirl": "laughing in real life",
    "liu": "Look It Up",
    "liv": "live",
    "liyf": "laughing in your face",
    "lj": "live journal",
    "lk": "like",
    "lke": "like",
    "llab": "Laughing like a bitch.",
    "llap": "live long and prosper",
    "llc": "laughing like crazy",
    "llf": "laugh like fuck",
    "llol": "literally laughing out loud",
    "lltnt": "live like theres no tomorrow ",
    "lm4aq": "Let's meet for a quickie.",
    "lma": "leave me alone",
    "lmamf": "leave me alone mother fucker",
    "lmao": "laughing my ass off",
    "lmaol": "laughing my ass out loud",
    "lmaomtoaoa": "Laugh my ass off many times over and over again",
    "lmaonade": "laughing my ass off",
    "lmaool": "laughing my ass off out loud ",
    "lmaootf": "Laughing my ass off on the floor ",
    "lmaorof": "Laughing my ass off Rolling on the floor",
    "lmaorotf": "laughing my ass off rolling on the floor",
    "lmaowrotf": "Laughing my ass of while rolling on the floor",
    "lmaowtntpm": "laughing my ass off whilst trying not to piss myself",
    "lmaoxh": "laughing my ass off extremely hard",
    "lmap": "leave me alone please",
    "lmb": "lick my balls",
    "lmbao": "laughing my black ass off",
    "lmbfwao": "laughing my big fat white ass off",
    "lmbo": "laughing my butt off",
    "lmcao": "laughing my crazy ass off",
    "lmclao": "laughing my cute little ass off",
    "lmd": "Lick My dick",
    "lmfao": "laughing my fucking ass off",
    "lmfbo": "laugh my fucking butt off",
    "lmffao": "laughing my fucking fat ass off",
    "lmffo": "Laughing my fucking face off",
    "lmfho": "laughing my fucking head off",
    "lmfo": "laughing my face off",
    "lmfpo": "laughing my fucking pussy off",
    "lmfr": "Lets Meet For Real",
    "lmfto": "laughing my fuckin tits off",
    "lmg": "let me guess",
    "lmgdao": "Laughing My God dicn ass Off",
    "lmgtfy": "Let me Google that for you",
    "lmhao": "laughing my hairy ass off",
    "lmho": "laughing my heiny off",
    "lmip": "LETS MEET IN PERSON",
    "lmirl": "Let's meet in real life",
    "lmk": "let me know",
    "lmks": "Let Me Know Soon",
    "lmkwut": "let me know what you think",
    "lml": "love my life",
    "lmmfao": "laughing my mother fucking ass off",
    "lmmfaos": "laughing my mother fucking ass off silly",
    "lmmfas": "laugh my mother fuckin ass off",
    "lmmffao": "laughing my mother fucking fat ass off",
    "lmo": "Leave Me One",
    "lmoao": "Laughing my Other ass Off",
    "lmp": "lick my pussy",
    "lmpo": "laughing my panties off",
    "lms": "leave me some",
    "lmsao": "laughing my sexy ass off",
    "lmso": "laughing my socks off",
    "lmtd": "limited",
    "lmtfa": "leave me the fuck alone",
    "lmto": "laughing my tits off",
    "lmtus": "let me tell you something",
    "lmty": "laughing more than you",
    "lmvo": "laugh my vagina off",
    "ln": "last name",
    "lnk": "Link",
    "lobfl": "Laugh Out Bloody fucking Loud",
    "lof": "Laughing on floor",
    "lofi": "uncool",
    "lofl": "laugh out fucking loud",
    "loflmao": "laying on floor laughing my ass off",
    "loi": "laughing on the inside",
    "lol": "laughing out loud",
    "lol'd": "laughed out loud",
    "lol2u": "Laugh out loud to you",
    "lol@u": "Laugh out loud at you",
    "lolarotf": "laughing out loud and rolling on the floor",
    "lolaw": "laugh out loud at work",
    "lolbs": "laugh out loud but seriously",
    "lolcano": "laugh out loud",
    "lolci": "laughing out loud, crying inside",
    "lolcity": "the whole city laughs out loud",
    "lold": "laughed out loud",
    "lolees": "laugh out loud",
    "lolerz": "laugh out loud",
    "lolf": "lots of love forever",
    "lolin": "laughing out loud",
    "lolio": "laugh out loud I own",
    "lollam": "Laughing Out Loud Like A Maniac",
    "lollercaust": "an extreme event of hilarity",
    "lollercoaster": "laugh out loud (a lot)",
    "lollerskates": "laughing out loud",
    "lolm": "laugh out loud man",
    "loln": "laught out loud... not",
    "lolngs": "laghing out loud never gonna stop",
    "lolocost": "laugh out loud",
    "lolol": "saying laugh out loud out loud",
    "lololz": "laugh out loud",
    "lolpimp": "Laughing out loud peeing in my pants",
    "lolq": "laugh out loud quietly",
    "lolrof": "Laughing out loud while rolling on the floor.",
    "lolrotf": "laughing out loud rolling on the floor",
    "lols": "laugh out loud ",
    "lolvq": "laugh out loud very quietly",
    "lolwtime": "laughing out loud with tears in my eyes",
    "lolz": "laugh out loud",
    "lomg": "like oh my god",
    "loml": "love of my life",
    "lomy": "love of my life",
    "loomm": "laughing out of my mind",
    "lorl": "laugh out real loud",
    "lorrl": "laugh out really really loud",
    "lotf": "laughing on the floor",
    "loti": "laughing on the inside",
    "loto": "laughing on the outside",
    "lotr": "lord of the rings",
    "lov": "love",
    "lovu": "love you",
    "loxen": "laughing out loud",
    "loxxen": "laughing out loud",
    "lozer": "loser",
    "lpb": "low ping bitched",
    "lpiaw": "Large Penis is always welcome",
    "lpms": "life pretty much sucks",
    "lq": "Laughing Quietly",
    "lq2m": "laughing quietly to myself",
    "lqtm": "Laugh quietly to myself",
    "lqtms": "Laughing quietly to myself",
    "lqts": "laughing quietly to self",
    "lrfl": "Laughing really fucking loud",
    "lrh": "laughing really hard",
    "lrqtms": "laughing really quietly to myself",
    "lrt": "last retweet",
    "lsfw": "Less Safe For Work",
    "lshic": "laughing so hard i'm crying",
    "lshid": "laugh so hard i die",
    "lshipmp": "Laughing so Hard I Piss My Pants",
    "lshismp": "laughed so hard I shit my pants",
    "lshiwms": "laughing so hard I wet myself",
    "lshmson": "laughing so hard milk shot out nose",
    "lshrn": "laughing so hard right now",
    "lsmih": "laughing so much it hurts",
    "lsr": "loser",
    "lsudi": "Lets see you do it",
    "lt": "long time",
    "ltb": "looking to buy",
    "lthtt": "laughing too hard to type",
    "ltip": "laughting until I puke",
    "ltm": "listen to me",
    "ltmq": "Laugh To Myself Quietly",
    "ltms": "Laughing to my self",
    "ltnc": "Long time no see",
    "ltns": "long time no see",
    "ltnsoh": "Long time, no see or hear",
    "ltnt": "long time no talk",
    "ltp": "Lay the pipe",
    "ltr": "later",
    "lttpot": "laughing to the point of tears",
    "ltw": "Lead The Way",
    "ltywl": "love the way you lie",
    "lu2": "love you too",
    "lu2d": "love you to death",
    "lu4l": "love you for life",
    "lub": "laugh under breath",
    "luf": "love",
    "luff": "Love",
    "lug": "lesbian until graduation",
    "luk": "look",
    "lukin": "looking",
    "lul": "love you lots",
    "lulab": "Love you like a brother",
    "lulas": "Love You Like a Sister",
    "lulz": "Laughing out loud.",
    "lurker": "one who reads but doesn't reply",
    "lurve": "love",
    "luser": "user who is a loser",
    "lusm": "love you so much",
    "luv": "love",
    "luver": "lover",
    "luvuvm": "love you very much",
    "luvv": "love",
    "luzar": "Loser",
    "lv": "love",
    "lve": "Love",
    "lvl": "level",
    "lvn": "loving",
    "lvr": "lover",
    "lvya": "love you",
    "lwih": "look what I have",
    "lwn": "last week's news",
    "ly": "love you",
    "ly2": "love you to",
    "lya": "love you always",
    "lyaab": "Love you as a brother",
    "lyaaf": "Love you as a friend",
    "lyao": "laugh your ass off",
    "lybo": "laugh your butt off",
    "lyf": "life",
    "lyfao": "laughing your fucking ass off",
    "lyfe": "life",
    "lyk": "like",
    "lyk3": "like",
    "lyke": "like",
    "lyl": "love you lots",
    "lylab": "love you like a brother",
    "lylaba": "love you like a brother always",
    "lylad": "love you like a dad",
    "lylafklc": "love you like a fat kid loves cake",
    "lylam": "love you like a mom",
    "lylas": "I love you like a sister",
    "lylasa": "love you like a sister always",
    "lylno": "Love you like no other",
    "lyls": "love you lots",
    "lymi": "love you mean it",
    "lysfm": "love you so fucking much",
    "lysm": "love you so much",
    "lyt": "love you too",
    "lyvm": "love you very much",
    "lzer": "laser",
    "lzr": "loser",
    "m": "am",
    "m$": "Microsoft",
    "m$wxp": "Microsoft Windows XP",
    "m&d": "mom and dad",
    "m'kay": "okay",
    "m.i.a": "Missing In Action",
    "m.o": "makeout",
    "m/b": "maybe",
    "m/f": "male or female",
    "m2": "me too",
    "m3": "me",
    "m473s": "friends",
    "m473z": "friends",
    "m4f": "male for female",
    "m4m": "male for male",
    "m8": "friend",
    "m84l": "mate for life",
    "m8s": "mates",
    "m8t": "mate",
    "m8t's": "friends",
    "m9": "mine",
    "mabby": "maybe",
    "mabe": "Maybe",
    "mah": "my",
    "mai": "my",
    "mao": "my ass off",
    "marvy": "marvelous",
    "masterb8": "masterbate",
    "mastrb8": "masturbate.",
    "mayb": "maybe",
    "mayte": "mate",
    "mb": "my bad",
    "mbf": "my best friend",
    "mbfal": "my best friend and lover",
    "mbhsm": "My Boobs Hurt So Much",
    "mbl8r": "Maybe Later",
    "mcds": "mcdonalds",
    "mcs": "My computer sucks",
    "mcse": "Microsoft Certified Systems Engineer",
    "me2": "me too",
    "meatcurtain": "woman's private parts",
    "meatspace": "the real world",
    "meeh": "me",
    "mego": "my eyes glaze over",
    "meh": "whatever",
    "messg": "message",
    "mf": "motherfucker",
    "mf2f4sx": "meet face to face for sex",
    "mfa": "mother fucking asshole",
    "mfah": "motherfucking asshole",
    "mfao": "my fucking ass off",
    "mfb": "mother fucking bitch",
    "mfg": "merge from current",
    "mfkr": "motherfucker",
    "mflfs": "married female looking for sex",
    "mfr": "motherfucker",
    "mfw": "my face when",
    "mgiwjsdchmw": "my girlfriend is watching jeff so don't call her my wife",
    "mhh": "my head hurts",
    "mhm": "Yes",
    "mho": "My Humble Opinion",
    "mia": "Missing In Action",
    "mic": "microphone",
    "miid": "my internet is down",
    "milf": "Mom i'd like to fuck",
    "miltf": "Mom I'd like to fuck",
    "min": "minute",
    "mins": "minutes",
    "miq": "make it quick",
    "mir": "mom in room",
    "mirl": "meet in real life",
    "misc.": "miscellaneous",
    "miself": "myself",
    "mite": "might",
    "miw": "mom is watching",
    "miwnlf": "mom I would not like to fuck.",
    "mk": "mmm....ok",
    "mkay": "ok",
    "mlc": "mid life crisis",
    "mle": "emily",
    "mlia": "my life is amazing",
    "mlod": "mega laugh out loud of doom",
    "mlp": "my little pony",
    "mmamp": "Meet me at my place",
    "mmas": "meet me after school",
    "mmatc": "meet me around the corner",
    "mmatp": "meet me at the park",
    "mmbocmb": "message me back or comment me back",
    "mmd": "make my day",
    "mmiw": "my mom is watching",
    "mmk": "umm, ok",
    "mml": "making me laugh",
    "mml8r": "meet me later",
    "mmlfs": "married man looking for sex",
    "mmmkay": "okay",
    "mmo": "Massive Multiplayer Online",
    "mmt": "meet me there",
    "mmtyh": "My mom thinks you're hot",
    "mmw": "making me wet",
    "mngmt": "management",
    "mngr": "manager",
    "mnm": "eminem",
    "mnt": "More next time",
    "mobo": "motherboard",
    "mof": "matter of fact",
    "mofo": "mother fucker",
    "moh": "Medal Of Honor",
    "mohaa": "Medal of Honor Allied Assult",
    "mol": "more or less",
    "mompl": "moment please",
    "moobs": "man boobs",
    "mor": "more",
    "morf": "male or female",
    "moro": "tomorrow",
    "mos": "mom over shoulder",
    "moss": "member of same sex",
    "motarded": "more retarded",
    "motd": "message of the day",
    "motos": "member of the opposite sex",
    "mpaw": "my parents are watching",
    "mpbis": "most popular boy in school",
    "mpd": "Multiple Personality Disorder",
    "mpgis": "most popular girl in school",
    "mph": "miles per hour",
    "mpih": "my penis is hard",
    "mpty": "more power to you",
    "mrau": "message received and understood",
    "msf": "male seeking female",
    "msg": "message",
    "msgs": "messages",
    "msh": "Me so horny",
    "msibo": "my side is busting open",
    "msie": "microsoft's internet explorer",
    "msm": "main stream media",
    "msmd": "monkey see - monkey do",
    "msngr": "messenger",
    "mssg": "message",
    "mstrb8r": "masturbator",
    "msv": "Microsoft Vista",
    "mtc": "more to come",
    "mtf": "More to Follow",
    "mtfbwu": "may the force be with you",
    "mtfbwy": "May the Force be with you",
    "mtg": "Meeting",
    "mtherfker": "mother fucker",
    "mthrfkr": "mother fucker",
    "mtl": "more than likely",
    "mtr": "matter",
    "mtrfkr": "motherfucker",
    "mty": "empty",
    "mu": "miss you",
    "mudda": "mother",
    "mul": "miss you lots",
    "musiq": "music",
    "musm": "Miss You So Much",
    "mutha": "mother",
    "muve": "multi-user virtual environment",
    "muvva": "mother",
    "muzik": "music",
    "mw2": "modern warfare 2",
    "mw3": "Modern Warfare 3",
    "mwah": "kiss",
    "mwf": "Married White Female",
    "mwsmirl": "maybe we should meet in real life",
    "myaly": "miss you and love you",
    "myfb": "mind your fucking business",
    "myke": "man-dyke",
    "myn": "mine",
    "myob": "mind your own business",
    "myodb": "mind your own dicn business",
    "myofb": "mind your own fucking business",
    "mypl": "my young padawan learner",
    "mysm": "Miss you so much",
    "myspce": "myspace",
    "mmorpg": "massively multiplayer online role playing game",
    "n": "and",
    "n e": "any",
    "n/a": "not applicable",
    "n/a/s/l": "name, age, sex location",
    "n/c": "no comment",
    "n/m": "nevermind",
    "n/n": "nickname",
    "n/o": "no offense",
    "n/t": "no text",
    "n00b": "newbie",
    "n00bs": "newbies",
    "n00dz": "nudes",
    "n00s": "news",
    "n1": "nice one",
    "n199312": "african american",
    "n1994": "african american",
    "n2": "into",
    "n2b": "not too bad",
    "n2bb": "nice to be back",
    "n2br": "not to be rude",
    "n2g": "Not too good",
    "n2m": "not too much",
    "n2mh": "not too much here",
    "n2mhbu": "not too much how about you?",
    "n2mhjc": "not too much here just chillin",
    "n2mu": "not too much, you?",
    "n2n": "need to know",
    "n2p": "need to pee",
    "n64": "Nintendo 64",
    "n8v": "native",
    "na": "not applicable",
    "na4w": "not appropriate for work",
    "naa": "not at all",
    "nade": "grenade",
    "nafc": "Not Appropriate for Children",
    "nafkam": "Not Away From Keyboard Any More",
    "naft": "Not A fucking Thing",
    "nafta": "North American Free Trade Agreement",
    "nah": "no",
    "namh": "not at my house",
    "nao": "Not As Often",
    "natch": "naturally",
    "natm": "not at the minute",
    "naw": "no",
    "naw-t": "Naughty",
    "nawidt": "never again will i do that",
    "nawt": "not",
    "naww": "no",
    "nayl": "in a while",
    "nb": "not bad",
    "nb,p": "nothing bad, parents",
    "nba": "national basketball association ",
    "nbd": "no big deal",
    "nbdy": "nobody",
    "nbf": "never been fucked",
    "nc": "not cool",
    "ncaa": "National Collegiate Athletic Association",
    "ncs": "no crap sherlock",
    "nd": "and",
    "ndit": "No details in thread",
    "ndn": "indian",
    "nds": "Nintendo DS",
    "ne": "any",
    "ne1": "anyone",
    "neday": "any day",
    "nedn": "any day now",
    "nefing": "anything",
    "nei": "Not enough information",
    "neida": "any idea",
    "nekkid": "naked",
    "nemore": "Anymore",
    "nes": "Nintendo Entertainment System",
    "nethin": "anything",
    "nething": "anything",
    "neva": "never",
    "nevah": "never",
    "nevar": "Never",
    "nevarz": "never",
    "nevm": "never mind",
    "nevr": "never",
    "newais": "Anyways",
    "neway": "anyway",
    "neways": "anyways",
    "newayz": "anyways",
    "newb": "someone who is new",
    "newbie": "new player",
    "newez": "anyways",
    "nf": "not funny",
    "nfbsk": "not for british school kids",
    "nfc": "no fucking clue",
    "nfd": "no fucking deal",
    "nff": "not fucking fair",
    "nfi": "no fucking idea",
    "nfr": "not for real",
    "nfs": "not for sale",
    "nft": "no further text",
    "nfw": "no fucking way",
    "ng": "nice game",
    "ngaf": "nobody gives a fuck",
    "ngl": "Not Gonna Lie",
    "nh": "nice hand",
    "nhatm": "not here at the moment",
    "ni": "no idea",
    "ni994": "nigga",
    "nib": "new in box",
    "nic": "Network Interface Card",
    "nif": "non internet friend",
    "nifoc": "naked in front of computer",
    "nifok": "naked in front of keyboard",
    "nigysob": "now I've got you son of a bitch",
    "nimby": "not in my backyard",
    "nin": "no its not",
    "nip": "nothing in particular",
    "nips": "nipples",
    "nite": "night",
    "nizzle": "nigger",
    "nj": "Nice job",
    "njoy": "enjoy",
    "njp": "nice job partner",
    "nk": "no kidding",
    "nkt": "never knew that",
    "nld": "nice lay down",
    "nm": "not much",
    "nm u": "not much, you",
    "nmbr": "number",
    "nme": "enemy",
    "nmf": "not my fault",
    "nmfp": "not my fucking problem",
    "nmh": "not much here",
    "nmhau": "nothing much how about you",
    "nmhm": "nothing much here, man",
    "nmhu": "nothing much here, you?",
    "nmhwby": "nothing much here what about you",
    "nmjb": "nothing much just bored",
    "nmjc": "not much, just chillin'",
    "nmjch": "Nothing Much Just Chilling",
    "nmjcu": "nothing much, just chilling, you?",
    "nmjdhw": "nothing much just doing homework",
    "nmjfa": "nothing much, just fucking around",
    "nmnhnlm": "no money, no honey, nobody loves me",
    "nmp": "Not My Problem",
    "nmu": "nothing much, you",
    "nmw": "no matter what",
    "nmwh": "no matter what happens",
    "nn": "good night",
    "nn2r": "no need to respond",
    "nnaa": "no not at all",
    "nnfaa": "no need for an apology",
    "nnr": "no not really",
    "nntr": "no need to reply",
    "nntst": "no need to say thanks",
    "no pro": "no problem",
    "no1": "no one",
    "noaa": "National Oceanic and Atmospheric Administration",
    "noc": "naked on camera",
    "noe": "know",
    "noes": "no",
    "nofi": "No Flame Intended",
    "nolm": "No one loves me",
    "nomw": "not on my watch",
    "noob": "someone who is new",
    "noobie": "new person",
    "nooblet": "new player",
    "noobz0r": "newbie",
    "noodz": "nude pictures",
    "nookie": "sex",
    "nop": "normal operating procedure",
    "norwich": "knickers off ready when I come home",
    "notin": "nothing",
    "noty": "no thank you",
    "noub": "none of your business",
    "nowai": "No way",
    "nowin": "knowing",
    "noyb": "none of your business",
    "noygdb": "none of your god dicn business",
    "np": "no problem",
    "np4np": "naked pic for naked pic",
    "npa": "not paying attention",
    "npc": "Non-playable character",
    "npe": "nope",
    "npgf": "no problem girl friend",
    "nph": "no problem here",
    "npi": "no pun intended",
    "npnt": "no picture, no talk",
    "nps": "No Problems",
    "nq": "Thank you",
    "nr": "no reserve",
    "nr4u": "not right for you",
    "nrg": "energy",
    "nrn": "No Response Necessary",
    "ns": "nice",
    "nsa": "No Strings Attached",
    "nsas": "No Strings Attached Sex",
    "nsfmf": "not so fast my friend",
    "nsfu": "no sex for you",
    "nsfw": "not safe for work",
    "nss": "no shit sherlock",
    "nst": "no school today",
    "nstaafl": "No Such Thing As a Free Lunch",
    "nt": "nice try",
    "ntb": "not to bad",
    "ntbn": "no text-back needed",
    "nthg": "nothing",
    "nthin": "nothing",
    "nthn": "nothing",
    "ntigaf": "not that i give a fuck",
    "ntk": "Need to know",
    "ntkb": "need to know basis",
    "ntm": "not to much",
    "ntmk": "Not to my knowledge",
    "ntmu": "nice to meet you",
    "ntmy": "nice to meet you",
    "ntn": "nothing",
    "ntrly": "Not Really",
    "nts": "note to self",
    "ntstt": "not safe to talk ",
    "ntt": "need to talk",
    "ntta": "nothing to talk about ",
    "nttawwt": "Not that there is anything wrong with that",
    "nttiawwt": "Not that there is anything wrong with that.",
    "ntty": "nice talking to you",
    "ntw": "not to worry",
    "ntxt": "no text",
    "nty": "no thank you",
    "nu": "new",
    "nub": "inexperienced person",
    "nuff": "enough",
    "nuffin": "nothing",
    "nufin": "nothing",
    "nutin": "nothing",
    "nuttin": "nothing",
    "nv": "envy",
    "nvm": "never mind",
    "nvmd": "nevermind",
    "nvmdt": "never mind then",
    "nvmt": "nevermind that",
    "nvr": "never",
    "nvrm": "Nevermind",
    "nvrmnd": "never mind ",
    "nw": "no way",
    "nwb": "a new person",
    "nwih": "no way in hell",
    "nwj": "No Way Jose",
    "nwrus": "no way are your serious ",
    "nws": "not work safe",
    "nwtf": "now what the fuck",
    "nwy": "no way",
    "nxt": "next",
    "ny1": "Anyone",
    "nyc": "New York City",
    "nyf": "not your fault",
    "nyp": "not your problem",
    "nywy": "anyway",
    "o": "Oh",
    "o rly": "oh really",
    "o&o": "over and out",
    "o.p.": "Original Poster",
    "o/y": "oh yeah",
    "oaoa": "over and over again",
    "oar": "on a roll",
    "oaw": "on a website",
    "obgjfioyo": "old but good job finding it on your own",
    "obj": "Object",
    "obl": "osama bin laden",
    "obo": "or best offer",
    "obtw": "oh, by the way",
    "obv": "obviously",
    "obvi": "obviously",
    "occ": "Occupation",
    "ocd": "obsessive compulsive disorder",
    "ocgg": "Oh Crap, gotta go",
    "od": "over dose",
    "oday": "software illegally obtained before it was released",
    "odg": "oh dear God",
    "odtaa": "one dicn thing after another",
    "oe": "or else",
    "oed": "oxford english dictionary",
    "of10": "often",
    "ofc": "of course",
    "ofcol": "oh for crying out loud",
    "ofn": "Old fucking News",
    "oftc": "out for the count",
    "oftn": "often",
    "oftpc": "off topic",
    "ofwg": "old fat white guys",
    "og": "original gangster",
    "ogw": "oh guess what",
    "oh noes": "oh shit!",
    "oh noez": "Oh no!",
    "ohic": "oh I see",
    "ohn": "oh hell no",
    "ohnoez": "Oh no",
    "ohy": "oh hell yeah",
    "oibmpc": "oops I broke my computer",
    "oic": "oh, I see",
    "oicic": "oh i see i see",
    "oicu": "oh, i see you!",
    "oicwydt": "oh, i see what you did there",
    "oidia": "oops i did it again",
    "oiyd": "Only In Your Dreams",
    "oj": "orange juice",
    "ojsu": "Oh, just shut up!",
    "ok": "okay",
    "oll": "online love",
    "olpc": "One Laptop Per Child",
    "omdg": "oh my dear god",
    "omdz": "Oh My Days ",
    "omfd": "oh my fucking days",
    "omfg": "oh my fucking god",
    "omfgn": "Oh my fucking god noob",
    "omfgsh": "Oh My fucking Gosh",
    "omfj": "oh my fucking jesus",
    "omfl": "oh my fucking internet connection is slow",
    "omfsm": "Oh My Flying Spaghetti Monster",
    "omfwtg": "Oh My fuck What The God?",
    "omg": "oh my God",
    "omg's": "oh my god's",
    "omgd": "Oh my gosh dude",
    "omgf": "oh my god...fuck!",
    "omgg": "Oh my gosh girl",
    "omgicfbi": "Oh my god I can't fucking believe it",
    "omgih": "Oh My God In Heaven",
    "omgihv2p": "oh my god i have to pee",
    "omginbd": "Oh my God, It's no big deal",
    "omgn": "oh my goodness",
    "omgny": "oh my god no way",
    "omgosh": "Oh my gosh",
    "omgroflmao": "oh my god roll on the floor laughing my ass off",
    "omgsh": "oh my gosh",
    "omgty": "Oh my god thank you",
    "omgukk": "oh my god you killed kenny",
    "omgwtf": "on my God, what the fuck",
    "omgwtfbbq": "oh my God, what the fuck",
    "omgwtfhax": "Oh My God What The fuck, Hacks!",
    "omgwtfit": "Oh my God, what the fuck is that",
    "omgwtfnipples": "on my God, what the fuck",
    "omgyg2bk": "oh my god you got to be kidding",
    "omgykkyb": "oh my god you killed kenny you bitcheds",
    "omgz": "oh my God",
    "omgzors": "oh my god",
    "omhg": "oh my hell god",
    "omj": "oh my jesus",
    "ommfg": "oh my mother fucking god",
    "omt": "one more time",
    "omw": "on my way",
    "omwh": "on my way home",
    "omwts": "on my way to school",
    "omy": "oh my!",
    "onoez": "oh no",
    "onoz": "oh no",
    "onud": "oh no you didn't",
    "onyd": "oh no you didn't",
    "oob": "out of buisness",
    "oobl": "out of breath laughing",
    "ooc": "out of character",
    "oohm": "out of his/her mind",
    "oom": "Out of mana",
    "oomf": "One of my followers",
    "oomm": "out of my mind",
    "ooo": "out of the office",
    "ootb": "out of the blue",
    "ootd": "outfit of the day",
    "oow": "On our way",
    "ooym": "out of your mind",
    "op": "operator",
    "orgy": "orgasm",
    "orlsx": "oral sex",
    "orpg": "online role playing game",
    "os": "operating system",
    "osbutctt": "only sad bitcheds use this crappy text talk",
    "osd": "On Screen Display",
    "osifgt": "oh shit i forgot",
    "oslt": "or something like that",
    "osy": "oh screw you",
    "ot": "off topic",
    "otc": "off the chain",
    "otfcu": "on the floor cracking up",
    "otfl": "on the floor laughing",
    "otflmao": "On the floor laughing my ass off",
    "otflmfao": "On the floor laughing my fucking ass off",
    "otflol": "on the floor laughing out loud",
    "otfp": "on the fucking phone",
    "otft": "over the fucking top",
    "oti": "on the internet",
    "otl": "out to lunch",
    "otoh": "on the other hand",
    "otp": "on the phone",
    "ots": "over the shoulder",
    "ott": "over the top",
    "otw": "on the way",
    "ova": "over",
    "oways": "oh wow are you serious",
    "owned": "made to look bad",
    "ownt": "made to look bad",
    "ownz": "owns",
    "ownzer": "one who makes others look bad",
    "ownzorz": "Owned.",
    "owt": "Out",
    "oww": "Oops, wrong window",
    "oyfe": "Open Your fucking Eyes",
    "oyid": "oh yes i did",
    "oyo": "on your own",
    "oyr": "Oh Yeah Right",
    "p-nis": "penis",
    "p.o.b.": "Parent Over Back",
    "p.o.s": "parent over shoulder",
    "p.o.s.": "parent over shoulder",
    "p/oed": "pissed off",
    "p/w": "password",
    "p00p": "poop",
    "p0wn": "make to look bad",
    "p2p": "peer to peer",
    "p33n": "penis",
    "p3n0r": "penis",
    "p3n15": "penis",
    "p3n1s": "penis",
    "p4p": "pic for pic",
    "p911": "parent emergency (parent near)",
    "p@w": "parents are watching",
    "pach": "parents are coming home",
    "pachs": "parents are coming home soon",
    "pae": "Pimpin aint easy",
    "pag": "Parents Are Gone",
    "pah": "parents at home",
    "parnts": "parents",
    "pas": "parent at side",
    "pasii": "put a sock in it",
    "patd": "Panic At The Disco",
    "paw": "parents are watching",
    "pb": "peanut butter",
    "pb&j": "peanut butter and jelly",
    "pbb": "parent behind back",
    "pbcakb": "problem between chair and keyboard",
    "pbj": "peanut butter and jelly",
    "pbjt": "peanut butter jelly time",
    "pbkc": "Problem between keyboard & chair",
    "pbly": "probably",
    "pbm": "parent behind me",
    "pbp": "Please Be Patient",
    "pcbd": "page cannot be displayed",
    "pce": "peace",
    "pcent": "percent",
    "pcm": "please call me",
    "pco": "please come over",
    "pcrs": "Parents can read slang",
    "pda": "public display of affection",
    "pdg": "pretty dicn good",
    "pdq": "pretty dicn quick",
    "peanus": "penis",
    "pearoast": "repost",
    "pebcak": "Problem Exists Between Chair and Keyboard",
    "pebkac": "problem exists between keyboard and chair",
    "pebmac": "Problem Exist Between monitor and chair",
    "peep dis": "check out what I'm telling you",
    "peeps": "people",
    "pen0r": "Penis",
    "pen15": "penis",
    "penor": "penis",
    "peoples": "people",
    "perv": "pervert",
    "pewp": "poop",
    "pex": "Please explain?",
    "pezzas": "parents",
    "pf": "profile ",
    "pfa": "Please Find Attached",
    "pfm": "Please forgive me",
    "pfo": "please fuck off",
    "pfos": "parental figure over sholder",
    "pfy": "pimply faced youth",
    "pg": "page",
    "ph#": "phone number",
    "ph33r": "fear",
    "ph34r": "fear",
    "phag": "fuc",
    "phail": "fail",
    "phat": "pretty hot and tasty",
    "phayl": "fail",
    "phear": "fear",
    "phlr": "peace hugs love respect",
    "phm": "please help me",
    "phq": "fuck you",
    "phreak": "freak",
    "phreaker": "phone hacker",
    "phuck": "fuck",
    "phucker": "fucker",
    "phuk": "fuck",
    "phun": "fun",
    "phux": "fuck",
    "phuxor": "fuck",
    "piab": "panties in a bunch",
    "pic": "picture",
    "piccies": "Pictures",
    "pics": "pictures",
    "pihb": "pee in his/her butt",
    "piihb": "put it in her butt",
    "piitb": "put it in the butt",
    "pima": "Pain in my ass",
    "pimfa": "pain in my fucking ass",
    "pimha": "Pain in my hairy ass",
    "pimpl": "pissing in my pants laughing",
    "pino": "Filipino",
    "pir": "parents in room",
    "pirlos": "parent in room looking over shoulder",
    "pita": "pain in the ass",
    "pitfa": "Pain In The fucking ass",
    "pitr": "parent in the room",
    "pitrtul": "parents in the room text you later",
    "piw": "Parent is watching",
    "pix": "pictures",
    "pk": "player kill",
    "pkemon": "pokemon",
    "pker": "player killer",
    "pking": "player killing",
    "pl": "parent looking",
    "pl0x": "please",
    "pl8": "plate",
    "plac": "parent looking at computer",
    "plams": "parents looking at my screen",
    "plars": "party like a rock star",
    "platcs": "parent looking at the computer screen",
    "ple's": "please",
    "pleaz": "please",
    "pleez": "please",
    "pleeze": "please",
    "pleze": "please",
    "pliz": "please",
    "plma": "please leave me alone ",
    "plmk": "please let me know",
    "plocks": "please",
    "plom": "parents looking over me",
    "plomb": "parents looking over my back",
    "ploms": "parent looking over my shoulder",
    "plos": "Parents Looking Over Shoulder",
    "plox": "please",
    "ploxxorz": "please",
    "pls": "please",
    "plse": "please",
    "plx": "please/thanks",
    "plywm": "play with me",
    "plz": "please",
    "plzkthx": "Please? OK, Thank you",
    "plzthx": "please? Thanks",
    "pmfji": "Pardon me for jumping in",
    "pmfsl": "piss my fucking self laughing",
    "pmg": "oh my God",
    "pmita": "pound me in the ass",
    "pmitap": "pound me in the ass prison",
    "pml": "pissing myself laughing",
    "pmo": "pissing me off",
    "pmp": "pissing my pants",
    "pmpl": "piss my pants laughing",
    "pmsfl": "Pissed Myself fucking Laughing",
    "pmsl": "piss my self laughing",
    "pnbf": "Potential new boy friend",
    "pnhlgd": "parents not home, let's get dirty",
    "pns": "penis",
    "pnus": "penis",
    "po": "piss off",
    "po po": "police",
    "po'd": "pissed off",
    "pob": "parent over back",
    "poc": "Piece of crap",
    "poed": "pissed off",
    "poets": "piss off early, tomorrow's Saturday",
    "poi": "point of interest",
    "poidnh": "Pics or it did not happen ",
    "pol": "parent over looking",
    "poms": "parent over my shoulder",
    "poo": "poop",
    "poontang": "female genitalia",
    "pooter": "Computer",
    "popo": "police",
    "poq": "Piss Off Quick",
    "pos": "Parent Over Shoulder",
    "poscs": "parents over sholder change subject",
    "posmbri": "parent over shoulder might be reading it",
    "potc": "pirates of the caribbean",
    "pots": "Plain Old Telephone Service",
    "pov": "point of view",
    "pow": "prisoner of war",
    "pp": "pee pee",
    "ppl": "people",
    "ppls": "people",
    "pplz": "people",
    "ppor": "post proof or recant",
    "ppppppp": "Prior Proper Planning Prevents Piss Poor Performance",
    "pr0": "professional",
    "pr0n": "porn",
    "pr0nz": "porn",
    "prblm": "Problem",
    "prd": "period",
    "preggers": "pregnant",
    "prego": "Pregnant",
    "prfct": "perfect",
    "prn": "porn",
    "prncpl": "principal",
    "prncss": "princess",
    "prnoscrn": "porn on screen",
    "pro": "professional",
    "prob": "problem",
    "probly": "probably",
    "probz": "probably",
    "prod": "product",
    "prolly": "Probably",
    "prollz": "probably",
    "pron": "porn",
    "proxie": "proxy",
    "prp": "please reply",
    "prsn": "person",
    "prty": "party",
    "prv": "private",
    "prvrt": "pervert",
    "prw": "parents are watching",
    "ps1": "Play Station 1",
    "ps2": "Play Station 2",
    "ps3": "Play Station 3",
    "psa": "Public Service Announcement",
    "psbms": "parent standing by my side",
    "psn": "playstation netwok",
    "psos": "parent standing over sholder",
    "psp": "playstation portable",
    "pssy": "pussy",
    "pst": "please send tell",
    "pt33n": "preteen",
    "ptbb": "pass the barf bag",
    "ptfo": "passed the fuck out",
    "pthc": "preteen hardcore",
    "ptl": "Praise the Lord",
    "pto": "Personal Time Off ",
    "ptw": "play to win ",
    "puh-leaze": "Please",
    "purty": "pretty",
    "puter": "Computer",
    "pvp": "player versus player",
    "pvt": "pervert",
    "pw": "parent watching",
    "pwb": "pussy whipped bitch",
    "pwcb": "parents watching close by",
    "pwd": "password",
    "pwn": "made to look bad",
    "pwn3d": "owned",
    "pwn3r": "owner",
    "pwnage": "Ownage",
    "pwnd": "owned",
    "pwned": "made to look bad",
    "pwner": "owner",
    "pwnt": "owned",
    "pwnz": "owns",
    "pwnzor": "owner",
    "pwob": "Parent watching over back",
    "pwoms": "parent watching over my shoulder",
    "pwor": "power",
    "pwos": "parent was over sholder",
    "pww": "parents were watching",
    "pxr": "punk rocker",
    "pydim": "put your dick in me",
    "pyfco": "put your freaking clothes on",
    "pyt": "pretty young thing",
    "pz": "peace",
    "pzled": "puzzled",
    "p^s": "parent over shoulder",
    "q2c": "quick to cum",
    "q33r": "Queer",
    "q4u": "question for you",
    "qed": "I've made my Point",
    "qfe": "quoted for emphasis",
    "qfmft": "quoted for motherfucking truth",
    "qft": "quoted for truth",
    "qft&gj": "quoted for truth and great justice",
    "ql": "cool",
    "qltm": "quietly laughing to myself",
    "qna": "question and answer",
    "qool": "cool",
    "qoolz": "cool",
    "qotd": "quote of the day",
    "qotsa": "queens of the stone age",
    "qoty": "quote of the year",
    "qpr": "quite pathetic really",
    "qpwd": "quit posting while drunk",
    "qq": "crying eyes",
    "qt": "cutie",
    "qt3.14": "cutie pie",
    "qte": "cutie",
    "qtpi": "cutie pie",
    "r": "are",
    "r-tard": "retard",
    "r.i.p.": "rest in peace",
    "r0x0rz": "rocks",
    "r2f": "Ready To fuck",
    "r8": "rate",
    "r8p": "rape",
    "r8pist": "rapist",
    "r8t": "rate",
    "ra2": "red alert 2 (game)",
    "ra3": "Red Alert 3 (game)",
    "raoflmao": "rolling around on floor laughing my ass off",
    "rawk": "Rock",
    "rawks": "rocks",
    "rawr": "roar",
    "rb@u": "right back at you",
    "rbau": "right back at you",
    "rbay": "right back at you",
    "rbm": "right behind me",
    "rbtl": "Read between the lines",
    "rbty": "right back to you",
    "rcks": "Rocks",
    "rcsa": "right click save as",
    "rcvd": "received",
    "rdy": "ready",
    "re": "reply",
    "re/rehi": "hello again",
    "reefer": "marijuana",
    "refl": "rolling on the floor laughing",
    "rehi": "hello again",
    "rele": "really",
    "rents": "parents",
    "rentz": "parents",
    "rep": "to represent",
    "reppin": "representing",
    "retrotextual": "One who is using out of date words and abbreviations while texting.",
    "rff": "really fucking funny",
    "rflmao": "rolling on the floor laughing my ass off",
    "rfn": "right fucking now",
    "rgr": "roger",
    "rhcp": "red hot chilli peppers",
    "rhgir": "really hot guy in room",
    "rhs": "right hand side",
    "ricl": "rolling in chair laughing",
    "rifk": "rolling on the floor laughing",
    "rihad": "Rot In Hell And Die",
    "rino": "republican in name only",
    "rite": "right",
    "ritjive": "non virgin",
    "rjct": "reject",
    "rl": "real life",
    "rlbf": "Real Life Boy Friend",
    "rlf": "Real Life Friend",
    "rlg": "really loud giggle",
    "rlgf": "Real Life Girl Friend",
    "rlly": "really",
    "rln": "real life name",
    "rly": "really",
    "rlz": "rules",
    "rlze": "realize",
    "rm": "room",
    "rme": "rolling my eyes",
    "rmr": "remember",
    "rmso": "Rock My socks off",
    "rn": "Right now",
    "rnt": "aren't",
    "ro": "rock out",
    "rockr": "rocker",
    "rodger": "affirmative",
    "rofalol": "roll on the floor and laugh out loud",
    "rofc": "Rolling On Floor Crying",
    "roffle": "rolling on the floor laughing",
    "roffle out loud": "rolling on the floor laughing out loud",
    "rofflecake": "rolling on the floor laughing",
    "rofflecopters": "rolling on the floor with laughter",
    "roffleol": "rolling on the floor laughing out loud",
    "roffles": "rolling on floor laughing",
    "rofflmfao": "rolling on the floor laughing my fucking ass",
    "rofl": "rolling on the floor laughing",
    "rofl&pmp": "rolling on floor laughing and peeing my pants",
    "roflao": "rolling on the floor laughing my ass off",
    "roflastc": "Rolling On Floor Laughing And Scaring The Cat",
    "roflcopter": "Rolling on the floor laughing",
    "roflcopters": "rolling on the floor laughing, VERY funny.",
    "roflkmd": "rolling on the floor laughing kicking my dog",
    "rofllh": "rolling on the floor laughing like hell",
    "roflmao": "rolling on the floor laughing my ass off",
    "roflmaoapimp": "rolling on the floor laughing my ass off and peeing in my pants",
    "roflmaool": "Rolling on the floor laughing my ass off out loud",
    "roflmaopmp": "rolling on the floor, laughing my ass off, pissing my pants",
    "roflmaouts": "Rolling on floor laughing my fucking ass off unable to speak",
    "roflmaowpimp": "rolling on floor laughing my ass off while peeing in my pants",
    "roflmbfao": "Rolling On Floor Laughing My Big Fat ass Off ",
    "roflmbo": "rolling on floor laughing my butt off",
    "roflmfaopimp": "rolling on the floor laughing my fucking ass off pissing in my pants",
    "roflmfaopmp": "rolling on flor laughing my fucking ass of peeing my pants",
    "roflmgao": "rolling on the floor laughing my gay ass off",
    "roflmgdao": "rolling on the floor laughing my god dicn ass off",
    "roflmgdmfao": "roling on floor laughing my god dicn mother fucking ass off",
    "roflmgo": "Rolling On Floor Laughing My Guts Out",
    "roflmho": "Rolling on the floor laughing my head off",
    "roflmiaha": "Rolling on the floor laughing myself into a heart attack",
    "roflmmfao": "rolling on the floor laughing my mother fucking ass off",
    "roflol": "rolling on floor laughing out loud",
    "roflolbag": "Rolling On The Floor Laughing Out Loud Busting A Gut",
    "roflpimp": "rolling on the floor laughing pissing in my pants",
    "roflpmp": "rolling on the floor laughing peeing my pants",
    "roflwtime": "Rolling on the Floor laughing with tears in my eyes",
    "rofpml": "rolling on the floor pissing myself laughing",
    "rofwl": "Rolling on the floor while laughing",
    "roger": "affirmative",
    "rogl": "rolling on ground laughing",
    "roglmfao": "rolling on ground laughing my fucking ass off",
    "roi": "Return On Investment",
    "roids": "steroids",
    "roj": "affirmative",
    "rol": "rolling over laugihng",
    "rolmao": "Rolling Over Laughing My ass Off",
    "rolmfao": "rolling over laughing my fucking ass off",
    "rombl": "rolled off my bed laughing",
    "rong": "wrong",
    "roofles": "rolling on the floor laughing",
    "ror": "raughing out roud",
    "rotf": "rolling on the floor",
    "rotfalol": "roll on the floor and laugh out loud",
    "rotffl": "roll on the fucking floor laughing",
    "rotfflmao": "rolling on the fucking floor laughing my ass off",
    "rotfflmfao": "rolling on the fucking floor laughing my fucking ass off",
    "rotfl": "rolling on the floor laughing",
    "rotflaviab": "rolling on the floor laughing and vomiting in a bucket",
    "rotflmao": "rolling on the floor laughing my ass off",
    "rotflmaofaktd": "Rolling on the floor laughing my ass off farted and killed the dog",
    "rotflmaool": "rolling on the floor laughing my ass off out loud",
    "rotflmaostc": "rolling on the floor laughing my ass off scaring the cat",
    "rotflmbo": "rolling on the floor laughing my butt off",
    "rotflmfao": "rolling on the floor laughing my fucking ass off",
    "rotflmfaopimp": "rolling on the floor laughing my fucking ass off peeing in my pants",
    "rotflmfaopmp": "rolling on the floor laughing my ass off pissin my pants",
    "rotflmfho": "rolling on the floor laughing my fucking head off",
    "rotflmho": "rolling on the floor laughing my head off",
    "rotflmmfao": "rolling on the floor laughing my mother fucking ass off",
    "rotflol": "rolling on the floor laughing out loud",
    "rotfpm": "rolling on the floor pissing myself",
    "rotfwlmao": "rolling on the floor while laughing my ass off",
    "rotg": "rolling on the ground",
    "rotgl": "roll on the ground laughing",
    "rotglmao": "rolling on the ground laughing my ass off",
    "rotw": "rest of the world",
    "rowyco": "rock out with your cock out",
    "rox": "rocks",
    "roxor": "rock",
    "roxorz": "rocks",
    "roxxor": "rock",
    "rp": "roleplay",
    "rpg": "role playing game",
    "rpita": "royal pain in the ass",
    "rplbk": "reply back",
    "rpo": "royally pissed off",
    "rq": "real quick",
    "rr": "rest room",
    "rrb": "restroom break",
    "rsn": "real soon now",
    "rsp": "respawn",
    "rspct": "respect",
    "rsps": "Runescape Private Server",
    "rta": "read the article",
    "rtard": "retard",
    "rtbq": "Read The Blinking Question",
    "rtf": "return the favor",
    "rtfa": "read the fucking article",
    "rtffp": "Read the fucking front page",
    "rtfm": "read the fucking manual",
    "rtfmfm": "read the fucking manual fucking moron",
    "rtfmm": "read the fucking manual moron",
    "rtfms": "Read The fucking Manual Stupid",
    "rtfp": "read the fucking post",
    "rtfq": "Read The fucking Question",
    "rtfs": "read the fucking summary",
    "rtfu": "Ready the fuck up",
    "rtg": "ready to go",
    "rtl": "report the loss",
    "rtm": "read the manual",
    "rtr": "Read the Rules",
    "rtry": "retry",
    "rts": "Real-time strategy",
    "ru": "are you",
    "ru18": "are you 18",
    "rua": "are you alone",
    "ruabog": "are you a boy or girl",
    "ruagoab": "are you a girl or a boy",
    "rubz2nt": "are you busy tonight",
    "rufkm": "are you fucking kidding me",
    "rugay": "are you gay",
    "rugta": "are you going to answer",
    "ruh": "are you horny",
    "ruk": "are you ok?",
    "rukm": "are you kidding me",
    "rumf": "Are you male or female",
    "ruok": "are you ok?",
    "rur": "are you ready",
    "rut": "are you there",
    "ruwm": "are you watching me",
    "rwb": "Rich White bitch",
    "ryt": "right",
    "ryte": "right",
    "*s*": "smile",
    "s'ok": "it's okay",
    "s'pose": "suppose",
    "s'up": "what is up",
    "s.i.n.g.l.e": "Stay intoxicated nightly, get laid everyday.",
    "s.i.t.": "stay in touch",
    "s.o.a.b.": "son of a bitch",
    "s.o.b.": "son of a bitch",
    "s.w.a.k.": "sealed with a kiss",
    "s/b": "should be",
    "s2a": "sent to all",
    "s2bu": "Sucks to be you",
    "s2r": "send to receive",
    "s2u": "same to you",
    "s2us": "Speak to you soon",
    "s3x": "Sex.",
    "s4se": "Sight For Sore Eyes",
    "s8ter": "skater",
    "sab": "slap a bitch",
    "sagn": "Spelling and Grammar Nazi",
    "sah": "sexy as hell",
    "sahm": "stay at home mom",
    "sase": "self addressed stamped envelope",
    "sbc": "sorry bout caps",
    "sbcg4ap": "strongbads cool game for attractive people",
    "sbd": "silent but deadly",
    "sblai": "stop babbaling like an idiot",
    "sbrd": "so bored",
    "sbs": "such bull shit",
    "sbt": "sorry bout that",
    "scnr": "sorry, I couldn't resist",
    "scool": "school",
    "scrilla": "money",
    "scrt": "secret",
    "scurred": "scared",
    "sd": "suck dick",
    "sdf^": "shut da fuck up",
    "sdk": "Software Development Kit",
    "sdlc": "Software Development Life Cycle",
    "sec": "second",
    "secks": "sex",
    "secksea": "Sexy",
    "secksy": "sexy",
    "sed": "said",
    "see through your eyes": "stye",
    "seg": "shit Eatin Grin",
    "seks": "sex",
    "sellin": "selling",
    "seo": "Search Engine Optimization",
    "serp": "search engine results page",
    "sexc": "sexy",
    "sexe": "sexy",
    "sexi": "Sexy",
    "sexii": "sexy",
    "sexilicious": "Very Sexy",
    "sexx0rz": "sex",
    "sez": "says",
    "sfam": "Sister from another mother",
    "sfe": "safe",
    "sfh": "So fucking Hot",
    "sfipmp": "so funny I peed my pants",
    "sfm": "so fucking much",
    "sfr": "so fucking random",
    "sfs": "so fucking stupid",
    "sfsg": "So far so good",
    "sfu": "shut the fuck up",
    "sfw": "safe for work",
    "sfwuz": "safe for work until zoomed",
    "sfy": "speak for yourself",
    "sg": "so good",
    "sgb": "straight/gay/bisexual",
    "sgbadq": "Search google before asking dumb questions",
    "sgi": "Still got it",
    "sgtm": "slightly gigling to myself",
    "sh": "shit happens",
    "shag": "fuck",
    "shawty": "girl",
    "shd": "should",
    "shexi": "sexy",
    "shexy": "sexy",
    "shiat": "shit",
    "shiet": "shit",
    "shite": "shit",
    "shiz": "shit",
    "shizit": "shit",
    "shiznat": "shit",
    "shiznit": "shit",
    "shizz": "shit",
    "shizzle": "shit",
    "shld": "should",
    "shmexy": "sexy",
    "shmily": "see how much i love you",
    "sho": "sure",
    "sho'nuff": "sure enough",
    "showin": "showing",
    "shrn": "so hot right now",
    "sht": "shit",
    "shtf": "shit hits the fan",
    "shud": "should",
    "shuddup": "Shut Up",
    "shup": "shut up",
    "shure": "sure",
    "shut^": "shut Up",
    "shwr": "shower",
    "shyat": "shit",
    "shyt": "shit",
    "siao": "school is almost over",
    "sibir": "sibling in room",
    "sic": "said in context",
    "sicl": "sitting in chair laughing",
    "sif": "as if",
    "sifn't": "as if not",
    "sig": "Signature",
    "siggy": "Signature",
    "silf": "Sister I'd Like To fuck",
    "simcl": "sitting in my chair laughing",
    "simclmao": "sitting in my chair laughing my ass off",
    "siol": "Shout It Out Loud",
    "sis": "sister",
    "sista": "Sister",
    "sitb": "sex in the but",
    "sitmf": "say it to my face",
    "siu": "suck it up",
    "siuya": "shove it up your ass",
    "sk": "spawn kill",
    "sk8": "skate",
    "sk8er": "skater",
    "sk8ing": "Skating",
    "sk8r": "skater",
    "sk8ter": "skater",
    "sk8tr": "skater",
    "sked": "schedule",
    "skeet": "ejaculate",
    "skewl": "school",
    "skhool": "school",
    "skillz": "skills",
    "skl": "School",
    "skool": "school",
    "skoul": "school",
    "sktr": "skater",
    "skwl": "school",
    "sl4n": "so long for now",
    "sleepin": "sleeping",
    "sleepn": "sleeping",
    "slf": "sexy little fuck",
    "slgb": "Straight/Lesbian/Gay/Bisexual",
    "slng": "slang",
    "slo": "slow",
    "slore": "shitty whore",
    "slos": "someone looking over shoulder",
    "slp": "sleep",
    "slt": "something like that",
    "sl^t": "shit ",
    "sm": "social media",
    "sm1": "someone",
    "smb": "see my blog",
    "smbd": "suck my big dick ",
    "smbt": "Suck my big toe",
    "smc": "suck my cock",
    "smd": "suck my dick",
    "smdb": "suck my dick bitch",
    "smdvq": "suck my dick quickly",
    "smeg": "fuck",
    "smexy": "sexy",
    "smf": "stupid motherfucker",
    "smfd": "suck my fucking dick",
    "smfpos": "stupid mother fucking piece of shit",
    "smh": "shaking my head",
    "smhb": "suck my hairy balls",
    "smho": "Screaming My Head Off",
    "smithwaws": "Smack me in the head with a wooden spoon",
    "smofo": "stupid mother fucker",
    "smst": "somebody missed snack time",
    "smt": "suck my tits",
    "smthin": "something",
    "smthng": "something",
    "smtm": "sometime",
    "smto": "Sticking My Tongue Out",
    "smtoay": "Sticking my tongue out at you",
    "sn": "screen name",
    "snafu": "situation normal all fucked up",
    "snafubar": "Situation Normal All fucked Up Beyond Any Recognition",
    "snes": "Super Nintendo Entertainment System",
    "snew": "what's new",
    "snf": "so not fair",
    "snl": "Saturday Night Live",
    "snm": "say no more",
    "snog": "kiss",
    "snogged": "kissed",
    "soa": "service oriented architecture ",
    "soab": "son of a btch",
    "soad": "system of a down",
    "soafb": "son of a fucking bitch",
    "sob": "son of a bitch",
    "sobs": "same, old, boring shit",
    "soc": "Same old crap",
    "soe": "service oriented enterprise",
    "sof": "smile on face",
    "sofas": "stepping out for a smoke",
    "sofs": "same old fucking shit",
    "soi": "service oriented infrastructure",
    "sok": "It's ok",
    "sokay": "it's okay",
    "sol": "shit outta luck",
    "som'm": "something",
    "som1": "someone",
    "somadn": "sitting on my ass doing nothing",
    "some1": "someone",
    "soml": "story of my life",
    "soo": "So",
    "soobs": "saggy boobs",
    "sool": "shit out of luck",
    "sop": "same old place",
    "sorg": "Straight or Gay",
    "sorreh": "sorry",
    "sorta": "sort of",
    "sos": "same old shit",
    "sosdd": "same old shit, different day",
    "sosg": "spouse over shoulder gone",
    "sot": "suck on this",
    "sotc": "stupid off topic crap",
    "sotr": "sex on the road",
    "sowi": "sorry",
    "sowwy": "sorry",
    "soz": "sorry",
    "spk": "speak",
    "sploits": "exploits",
    "sploitz": "exploits",
    "spos": "stupid peace of shit",
    "sprm": "sperm",
    "sqtm": "snickering quietly to myself",
    "srch": "search",
    "srly": "seriously",
    "sroucks": "that's cool, but it still sucks",
    "srry": "sorry",
    "srs": "serious",
    "srsly": "seriously",
    "srvis": "Service",
    "sry": "sorry",
    "srynd2g": "sorry need to go",
    "srzly": "seriously",
    "ss": "screenshot",
    "ss4l": "smoking sista for life",
    "ssdd": "same shit, different day",
    "ssdp": "same shit different pile",
    "ssia": "subject says it all",
    "ssl": "secure sockets layer",
    "ssob": "stupid sons of bitches",
    "ssry": "so sorry",
    "sssd": "Same shit Same Day",
    "st": "Stop That",
    "st1": "stoned",
    "st8": "state",
    "stb": "soon to be",
    "stbx": "soon to be ex",
    "stby": "sucks to be you",
    "std": "sexually transmitted disease",
    "steamloller": "Laughing. Alot.",
    "stfd": "sit the fuck down",
    "stff": "stuff",
    "stfm": "search the fucking manual",
    "stfng": "search the fucking news group",
    "stfu": "shut the fuck up",
    "stfua": "shut the fuck up already",
    "stfuah": "shut the fuck up asshole",
    "stfub": "shut the fuck up bitch",
    "stfuda": "Shut the fuck up dumb ass",
    "stfugbtw": "shut the fuck up and get back to work",
    "stfun": "Shut the fuck up nigger",
    "stfuogtfo": "Shut the fuck up or get the fuck out.",
    "stfuppercut": "shut the fuck up",
    "stfuyb": "shut the fuck up you bitch",
    "stfuysoab": "shut the fuck up you son of a bitch",
    "stfw": "search the fucking web",
    "stg": "swear to god",
    "sth": "something",
    "sthing": "something",
    "sthu": "shut the hell up",
    "stm": "smiling to myself",
    "stoopid": "stupid",
    "stpd": "stupid",
    "str8": "straight",
    "str8up": "straight up",
    "sts": "so to speak",
    "stsp": "Same Time Same Place",
    "stt": "Same time tomorrow",
    "stufu": "stupid fucker",
    "stupd": "stupid",
    "stw": "share the wealth ",
    "stys": "speak to you soon",
    "su": "shut up",
    "suabq": "shut up and be quiet",
    "suagooml": "shut up and get out of my life",
    "suib": "shut up im busy",
    "suk": "suck",
    "suka": "Sucker",
    "sukz": "sucks",
    "sul": "see you later",
    "sum1": "someone",
    "sumfin": "Something",
    "summin": "something",
    "sumone": "someone",
    "sumthin'": "Something",
    "sumtin": "something",
    "sup": "what's up",
    "supa": "super",
    "supposably": "Supposedly",
    "sus": "see you soon",
    "susfu": "situation unchanged, still fucked up",
    "sut": "see you tomorrow",
    "sutuct": "so you think you can type",
    "sux": "sucks",
    "sux0rz": "sucks",
    "sux2bu": "sucks to be you",
    "suxor": "Sucks",
    "suxors": "sucks",
    "suxorz": "sucks",
    "suxx": "sucks",
    "suxxor": "sucks",
    "suyah": "shut up you ass hole!",
    "svn": "seven",
    "svu": "special victims unit",
    "sw": "so what",
    "swafk": "sealed with a friendly kiss",
    "swak": "sealed with a kiss",
    "swakaah": "Sealed With A Kiss And A Hug",
    "swalk": "sealed with a loving kiss",
    "swf": "single white female",
    "swm": "single white male",
    "swmbo": "she who must be obeyed",
    "swmt": "Stop Wasting My Time ",
    "swp": "sorry wrong person",
    "swsw2b": "single when she wants to be",
    "swt": "sweet",
    "swtf": "seriously, what the fuck",
    "sx": "sex",
    "sxc": "sexy",
    "sxcy": "sexy",
    "sxe": "straight edge",
    "sxi": "sexy",
    "sxs": "sex",
    "sxy": "sexy",
    "syatp": "see you at the party",
    "sydim": "stick your dick in me",
    "sydlm": "Shut your dirty little mouth",
    "syfm": "shut your fucking mouth",
    "syiab": "see you in a bit",
    "syiaf": "see you in a few",
    "syl": "see you later",
    "syl8r": "see you later",
    "sym": "shut your mouth",
    "syoa": "Save Your Own ass",
    "syotbf": "see you on the battlefield",
    "syrs": "see ya real soon",
    "sys": "see you soon",
    "sysop": "system operator",
    "syt": "see you there",
    "sytycd": "so you think you can dance ",
    "syu": "sex you up",
    "sz": "sorry",
    "t#3": "the",
    "t,ftfy": "there, fixed that for you",
    "t.t.y.l": "Talk To You Later",
    "t/a": "Try again",
    "t2b": "time to blunt",
    "t2m": "talk to me",
    "t2u": "talking to you",
    "t2ul": "talk to you later",
    "t2ul8r": "talk to you later",
    "t3h": "the",
    "t4a": "thanks for asking",
    "t4m": "Transgender for Male",
    "t4f": "Transgender for Female",
    "t4w": "Transgender for Woman",
    "t8st": "taste",
    "ta": "thanks again",
    "taci": "that's a crappy idea",
    "tafn": "That's all for now",
    "taht": "that",
    "tai": "think about it",
    "taig": "That's all I got. ",
    "tal": "thanks a lot",
    "tanq": "thank you",
    "tanstaafl": "there ain't no such thing as a free lunch",
    "tard": "retard",
    "tarfu": "things are really fucked up",
    "tat": "that",
    "tat2": "tattoo",
    "tau": "thinking about you",
    "taunch": "te amo un chingo",
    "taw": "Teachers are Watching",
    "tay": "thinking about you",
    "tb": "text back",
    "tb4u": "too bad for you",
    "tba": "to be anounced",
    "tbc": "To be continued",
    "tbd": "to be decided",
    "tbf": "to be fair",
    "tbfh": "to be fucking honest",
    "tbfu": "too bad for you",
    "tbh": "to be honest",
    "tbhimo": "to be honest in my opinion",
    "tbnt": "thanks but no thanks",
    "tbp": "The Pirate Bay",
    "tbpfh": "To be perfectly fucking honest",
    "tbph": "To be perfectly honest",
    "tbqf": "to be quite frank",
    "tbqh": "to be quite honest",
    "tbss": "too bad so sad",
    "tbtfh": "to be totally freaking honest",
    "tbvh": "to be very honest",
    "tc": "take care",
    "tcfc": "Too Close For Comfort",
    "tcfm": "too cool for me",
    "tcg": "Trading Card Game",
    "tchbo": "Topic creater has been owned",
    "tcial": "The cake is a lie",
    "tcoy": "take care of yourself",
    "tcp": "transmission control protocol",
    "tcp/ip": "transmission control protocol/internet protocol",
    "td2m": "talk dirty to me",
    "tddup": "till death do us part",
    "tdf": "To Die For",
    "tdl": "Too dicn Lazy",
    "tdtm": "Talk Dirty To Me",
    "tdwdtg": "The Devil Went Down To Georgia",
    "te": "Team effort",
    "teh": "the",
    "teotwawki": "the end of the world as we know it",
    "terd": "shit",
    "tf2": "Team Fortress 2",
    "tfa": "the fucking article",
    "tfb": "time for bed",
    "tfbundy": "totaly fucked but unfortunatly not dead yet",
    "tfc": "Team Fortress Classic",
    "tfd": "total fucking disaster",
    "tff": "That's fucking Funny",
    "tfft": "thank fuck for that",
    "tffw": "Too funny for words",
    "tfh": "Thread from hell",
    "tfic": "Tongue Firmly In Cheek",
    "tfiik": "the fuck if i know",
    "tfl": "Thanks For Looking",
    "tfln": "thanx for last night",
    "tfm": "too fucking much",
    "tfs": "thanks for sharing",
    "tfta": "thanks for the add",
    "tfti": "thanks for the information",
    "tfu": "that's fucked up",
    "tfu2baw": "time for you to buy a watch",
    "tg": "thank god",
    "tgfe": "together forever",
    "tgfitw": "The Greatest Fans In The World",
    "tgft": "thank god for that",
    "tgfu": "too good for you",
    "tgfuap": "thank god for unanswered prayers",
    "tghig": "thank god husband is gone",
    "tgif": "thank god it's friday",
    "tgiff": "thank god its fucking Friday",
    "tgis": "thank god it's saturday",
    "tgiwjo": "Thank God It Was Just Once",
    "tgsttttptct": "thank God someone took the time to put this crap together",
    "tgtbt": "Too Good To Be True",
    "tgwig": "thank god wife is gone",
    "tgws": "that goes without saying",
    "th@": "that",
    "tha": "the",
    "thankies": "Thank You",
    "thankx": "thank you",
    "thanq": "thank you",
    "thanx": "thank you",
    "thar": "there",
    "thatz": "that's",
    "thku": "thank you",
    "thn": "then",
    "thnk": "think",
    "thnx": "thanks",
    "tho": "though",
    "thot": "the hoe of today",
    "thr": "there",
    "thr4": "therefore",
    "thru": "through",
    "tht": "that",
    "thwdi": "thats how we do it",
    "thwy": "the hell with you!",
    "thx": "thank you",
    "thxx": "thanks",
    "thz": "thank you",
    "ti2o": "that is too obious",
    "tia": "thanks in advance",
    "tiafayh": "Thanks in advance for all your help",
    "tiai": "take it all in",
    "tias": "Try It And See",
    "tiatwtcc": "this is a trap word to catch copiers",
    "tif": "this is fun",
    "tif2m": "this is fucking 2 much",
    "tifs": "this is funny shit",
    "tifu": "that is fucked up",
    "tigger": "tiger",
    "tiic": "the idiots in control",
    "til": "until",
    "tilf": "Teenager I'd Like To fuck",
    "tinf": "this is not fair",
    "tinla": "this is not legal advice",
    "tinstaafl": "There Is No Such Thing As A Free Lunch",
    "tioli": "take it or leave it",
    "tis": "is",
    "tisc": "that is so cool",
    "tisfu": "that is so fucked up",
    "tisg": "this is so gay",
    "tisly": "that is so last year",
    "tisnf": "that is so not fair",
    "tiss": "This is some shit",
    "tisw": "that is so wrong",
    "tiw": "teacher is watching",
    "tix": "tickets",
    "tjb": "thats just boring",
    "tk": "team kill",
    "tk2ul": "talk to you later",
    "tkd": "Tae Kwon Do",
    "tker": "team killer",
    "tks": "thanks",
    "tku": "thank you",
    "tl": "Tough Luck",
    "tl,dr": "Too long; didn't read",
    "tl8r": "talk later",
    "tl:dr": "Too Long; Didn't Read",
    "tl; dr": "To Long; Didn't read",
    "tl;dr": "too long; didn't read",
    "tla": "Three Letter Acronym",
    "tlc": "tender loving care",
    "tld": "told",
    "tldnr": "too long, did not read",
    "tldr": "Too long, didn't read.",
    "tlgo": "The list goes on",
    "tliwwv": "this link is worthless without video",
    "tlk": "talk",
    "tlk2me": "talk to me",
    "tlk2ul8r": "talk to you later",
    "tlkin": "talking",
    "tlkn": "talking",
    "tltpr": "Too long to proof read.",
    "tlyk": "to let you know",
    "tma": "take my advice",
    "tmaai": "tell me all about it",
    "tmai": "tell me about it",
    "tmbi": "tell me about it",
    "tmi": "too much information",
    "tmk": "to my knowledge",
    "tml": "tell me later",
    "tmmrw": "tomorrow",
    "tmnt": "teenage mutant ninja turtles",
    "tmo": "take me out",
    "tmoro": "tomorrow",
    "tmoz": "tomorrow",
    "tmr": "tomorrow",
    "tmr@ia": "the monkeys are at it again",
    "tmrrw": "tomorrow",
    "tmrw": "Tomorrow",
    "tmrz": "tomorrow",
    "tms": "that makes sense",
    "tmsaisti": "That's my story and I'm sticking to it.",
    "tmsg": "tell me something good",
    "tmsidk": "tell me somthing I don't know",
    "tmth": "too much to handle",
    "tmtmo": "text me tomorrow",
    "tmtoyh": "Too Much Time On Your Hands",
    "tmtt": "tell me the truth",
    "tmw": "Too much work",
    "tmwfi": "Take my word for it",
    "tmz": "tomorrow",
    "tn1": "trust no-one",
    "tna": "tits and ass",
    "tnf": "That's Not Funny",
    "tnlnsl": "Took nothing left nothing signed log",
    "tnx": "thanks",
    "tnxz": "thanks",
    "tob": "teacher over back",
    "tofy": "Thinking of You",
    "toh": "typing one handed",
    "tok": "That's ok",
    "tok2ul8r": "i'll talk to you later",
    "tolol": "thinking of laughing out loud",
    "tomm": "tommorow",
    "tomoz": "tomorrow",
    "tos": "terms of service",
    "totes": "totally",
    "totl": "total",
    "totm": "top of the morning",
    "totp": "talking on the phone",
    "totpd": "top of the page dance",
    "tou": "thinking of you",
    "toya": "thinking of you always",
    "tp": "toilet paper",
    "tpb": "the pirate bay",
    "tpiwwp": "this post is worthless without pictures",
    "tps": "test procedure specification",
    "tptb": "the powers that be",
    "tq": "Thank You",
    "trani": "transexual",
    "tranny": "Transexual",
    "trble": "trouble",
    "trd": "tired",
    "trnsl8": "translate",
    "trnsltr": "translator",
    "troll": "person who diliberately stirs up trouble",
    "tru": "true",
    "ts": "talking shit",
    "tsc": "that's so cool",
    "tsff": "thats so fuckin funny",
    "tsig": "that site is gay",
    "tsnf": "that's so not fair",
    "tss": "That's so sweet",
    "tstoac": "too stupid to own a computer",
    "tswc": "tell someone who cares",
    "tt4n": "ta ta for now",
    "ttbc": "Try to be cool",
    "ttbomk": "to the best o fmy knowledge",
    "ttc": "text the cell",
    "ttfaf": "Through the Fire and Flames",
    "ttfn": "ta ta for now",
    "tthb": "try to hurry back",
    "ttihlic": "try to imagine how little i care",
    "ttiuwiop": "this thread is useless without pics",
    "ttiuwop": "this thread is useless without pics",
    "ttiuwp": "This Thread Is Useless Without Pictures",
    "ttiwwop": "This thread is worthless without pics",
    "ttiwwp": "this thread is worthless without pics",
    "ttl": "total",
    "ttlly": "totally",
    "ttly": "totally",
    "ttm": "talk to me",
    "ttml": "talk to me later",
    "ttms": "talking to myself",
    "ttr": "time to run",
    "ttrf": "That's the rules, fucker",
    "tts": "text to speech",
    "ttt": "to the top",
    "ttth": "Talk To The Hand",
    "tttt": "to tell the truth",
    "ttul": "Talk To You Later",
    "ttul8r": "Talk to you later",
    "ttus": "talk to you soon",
    "ttut": "Talk to you Tomorrow",
    "ttutt": "to tell you the truth",
    "tty": "Talk to You",
    "ttyab": "Talk to you after breakfast",
    "ttyad": "Talk to you after Dinner",
    "ttyal": "Talk to you after lunch",
    "ttyas": "talk to you at school",
    "ttyiam": "talk to you in a minute",
    "ttyitm": "talk to you in the morning",
    "ttyl": "talk to you later",
    "ttyl8r": "talk to you later",
    "ttylo": "talk to you later on",
    "ttylt": "talk to you later today",
    "ttyn": "talk to you never",
    "ttyna": "talk to you never again",
    "ttynl": "talk to you never loser",
    "ttynw": "talk to you next week",
    "ttyo": "talk to you online",
    "ttyob": "tend to your own business",
    "ttyotp": "talk to you on the phone",
    "ttyrs": "talk to you really soon",
    "ttys": "talk to you soon",
    "ttyt": "talk to you tomorrow",
    "ttytm": "talk to you tomorrow",
    "ttytt": "to tell you the truth",
    "ttyw": "talk to you whenever",
    "ttywl": "Talk to you way later",
    "tu": "thank you",
    "tuff": "tough",
    "tuh": "to",
    "tut": "take your time",
    "tuvm": "thank you very much",
    "tv": "television",
    "tvm": "thanks very much",
    "tw": "Teacher Watching",
    "twajs": "That was a joke, son.",
    "twat": "vagina",
    "twbc": "that would be cool",
    "twdah": "that was dumb as hell",
    "twf": "That was funny",
    "twfaf": "thats what friends are for",
    "twg": "That was great",
    "twi": "Texting While Intoxicated",
    "twis": "that's what I said",
    "twoh": "typing with one hand",
    "tws2wa": "That was so 2 weeks ago",
    "twss": "That's what she said",
    "twsy": "That was so yeterday",
    "twttr": "twitter",
    "twvsoy": "that was very stupid of you",
    "twyl": "Talk With You Later",
    "twys": "Talk With You Soon",
    "tx": "thanks",
    "txs": "thanks",
    "txt": "text",
    "txting": "texting",
    "txtyl": "text you later",
    "ty": "thank you",
    "tyclos": "turn your CAPS LOCK off, stupid",
    "tyfi": "Thank You for invite",
    "tyfn": "thank you for nothing",
    "tyfyc": "Thank You For Your Comment",
    "tyfyt": "Thank you for your time",
    "tyl": "text you later",
    "tym": "time",
    "tyme": "time",
    "typ": "thank you partner",
    "typo": "typing mistake",
    "tyred": "tired",
    "tys": "Told You So",
    "tysfm": "thank you so fucking much",
    "tysm": "thank you so much",
    "tysvm": "thank you so very much",
    "tyt": "take your time",
    "tyto": "take your top off",
    "tyty": "thank you thank you",
    "tyvm": "Thank You Very Much",
    "tyvvm": "thank you very very much",
    "u": "you",
    "u iz a 304": "you is a hoe",
    "u'd": "you would",
    "u'll": "you will",
    "u'r": "you're",
    "u'v": "you have",
    "u've": "You've",
    "u/l": "upload",
    "u/n": "username",
    "u2": "You too",
    "u2u": "up to you",
    "u4i": "up for it",
    "ua": "user agreement",
    "uaaaa": "Universal Association Against Acronym Abuse",
    "uat": "User Acceptance Testing",
    "uayor": "Use At Your Own Risk",
    "ub3r": "super",
    "uber": "over",
    "uctaodnt": "you can't teach an old dog new tricks",
    "udc": "you don't care",
    "udek": "you don't even know",
    "uds": "you dumb shit",
    "udwk": "you don't want to know",
    "udy": "you done yet",
    "ufab": "ugly fat ass bitch",
    "ufia": "unsolicited finger in the anus",
    "ufic": "Unsolicited Finger in Chili",
    "ufmf": "you funny mother fucker",
    "ufr": "Upon further review",
    "ugba": "you gay bitch ass",
    "ugtr": "you got that right",
    "uhab": "you have a blog",
    "uhems": "you hardly ever make sense",
    "ui": "User Interface",
    "ujds": "u just did shit",
    "ukr": "You know right",
    "ukwim": "you know what i mean",
    "ul": "unlucky",
    "ulbom": "you looked better on myspace",
    "umfriend": "sexual partner",
    "un2bo": "you need to back off",
    "un4rtun8ly": "unfortunately",
    "unt": "until next time",
    "uom": "You owe me",
    "upcia": "unsolicited pool cue in anus",
    "upia": "unsolicited pencil in anus",
    "upmo": "You piss me off",
    "upos": "you piece of shit",
    "upw": "unidentified party wound",
    "ur": "your",
    "ur2g": "you are too good",
    "ur6c": "you're sexy",
    "ura": "you are a",
    "uradrk": "you're a dork",
    "urafb": "you are a fucking bitch",
    "uraqt": "you are a cutie",
    "urcrzy": "you are crazy",
    "ure": "you are",
    "urg": "you are gay",
    "urht": "you're hot",
    "url8": "you are late",
    "urms": "you rock my socks",
    "urmw": "you are my world",
    "urnc": "you are not cool",
    "urs": "yours",
    "ursab": "you are such a bitch",
    "ursdf": "you are so dicn fine",
    "ursg": "you are so gay",
    "ursh": "you are so hot",
    "urssb": "you are so sexy baby",
    "urstpid": "you are stupid",
    "urstu": "you are stupid",
    "urtb": "you are the best",
    "urtbitw": "You are the best in the world!",
    "urtrd": "you retard",
    "urtw": "you are the worst",
    "urw": "you are weird",
    "uryyfm": "you are too wise for me",
    "usck": "you suck",
    "usd": "United States Dollar",
    "ussr": "The Union of Soviet Socialist Republics",
    "usuk": "You Suck",
    "usux": "you suck",
    "uta": "up the ass",
    "utfs": "Use the fucking search",
    "utfse": "use the fucking search engine",
    "utm": "you tell me",
    "uttm": "you talking to me?",
    "utube": "youtube",
    "utw": "used to work",
    "uty": "it's up to you",
    "uve": "You've",
    "uvgtbsm": "you have got to be shiting me",
    "uw": "you're welcome",
    "uwc": "you are welcome",
    "uya": "up your ass",
    "uyab": "up your ass bitch",
    "v4g1n4": "vagina",
    "vag": "vagina",
    "vajayjay": "vagina",
    "vb": "visual basic",
    "vbeg": "very big evil grin",
    "vbg": "very big grin",
    "vf": "very funny",
    "vfe": "Virgins 4 ever",
    "vff": "Verry fucking Funny",
    "vfm": "value for money",
    "vgg": "very good game",
    "vgh": "Very good hand",
    "vgl": "very good looking",
    "vgn": "Video Game Nerd",
    "vid": "Video",
    "vids": "Videos",
    "vip": "very important person",
    "vleo": "Very Low Earth Orbit",
    "vlog": "video log",
    "vn": "very nice",
    "vnc": "Virtual Network Computing",
    "vnh": "Very nice hand",
    "voip": "voice over ip",
    "vrsty": "Varsity",
    "vry": "very",
    "vwd": "very well done",
    "vweg": "very wicked evil grin",
    "vzit": "visit",
    "vzn": "verizon",
    "w'sup": "what's up",
    "w.b.s.": "Write Back Soon",
    "w.e": "Whatever",
    "w.e.": "whatever",
    "w.o.w": "World of Warcraft",
    "w.o.w.": "world of warcraft",
    "w/": "with",
    "w/b": "write back",
    "w/e": "whatever",
    "w/end": "weekend",
    "w/eva": "whatever",
    "w/o": "with out",
    "w/out": "without",
    "w/u": "with you",
    "w00t": "woohoo",
    "w012d": "word",
    "w2d": "what to do",
    "w2f": "want to fuck",
    "w2g": "Way to go",
    "w2ho": "want to hang out",
    "w2m": "want to meet",
    "w33d": "weed",
    "w8": "wait",
    "w8am": "wait a minute",
    "w8ing": "waiting",
    "w8t4me": "wait for me",
    "w8ter": "waiter",
    "w911": "Wife in room",
    "wab": "what a bitch",
    "wad": "without a doubt",
    "wad ^": "what's up?",
    "wadr": "with all due respect",
    "wadzup": "What's up?",
    "waf": "weird as fuck",
    "wafda": "What a fucking Dumb ass",
    "wafl": "what a fucking loser",
    "wafm": "wait a fucking minute",
    "wafn": "what a fucken noob",
    "wai": "what an idiot",
    "waloc": "what a load of crap",
    "walstib": "what a long strange trip it's been",
    "wam": "wait a minute",
    "wamh": "with all my heart",
    "wan2tlk": "Want to talk",
    "wana": "want to",
    "wanafuk": "wanna fuck",
    "wanker": "masturbater",
    "wanking": "Masturbating",
    "wanna": "want to",
    "wansta": "wanna be ganster",
    "warez": "illegally obtained software",
    "wassup": "what's up?",
    "wasup": "What's Up",
    "was^": "What's Up",
    "wat": "what",
    "wat's^": "Whats Up",
    "watcha": "what are you",
    "watev": "whatever",
    "wateva": "whatever ",
    "watevr": "whatever",
    "watevs": "whatever",
    "wats": "whats",
    "wats ^": "whats up",
    "wats^": "what's up?",
    "watz ^": "What's up",
    "wau": "what about you",
    "waug": "Where are you going",
    "wauw": "what are you wearing",
    "wau^2": "what are you up to?",
    "waw": "what a whore",
    "waycb": "when are you coming back",
    "wayd": "what are you doing",
    "waygow": "who are you going out with",
    "wayh": "why are you here",
    "wayn": "Where Are You Now",
    "waysttm": "why are you still talking to me",
    "waysw": "Why are you so weird",
    "wayt": "What are you thinking?",
    "wayta": "what are you talking about",
    "wayut": "what are you up to",
    "waz": "what is",
    "waz ^": "what's up",
    "wazz": "what's",
    "wazza": "what's up",
    "wazzup": "what's up",
    "waz^": "what's up?",
    "wb": "welcome back",
    "wbagnfarb": "would be a good name for a rock band",
    "wbb": "will be back",
    "wbbs": "will be back soon",
    "wbp": "Welcome Back Partner",
    "wbrb": "Will be right back",
    "wbs": "write back soon",
    "wbu": "what about you",
    "wby": "what about you",
    "wc": "who cares",
    "wc3": "Warcraft III",
    "wcutm": "what can you tell me",
    "wcw": "webcam whore",
    "wd": "well done",
    "wdf": "Worth Dying For",
    "wdhlm": "why doesnt he love me?",
    "wdidn": "what do i do now",
    "wdim": "What Did I miss",
    "wdtm": "what does that mean",
    "wduc": "what do you care",
    "wdum": "what do you mean",
    "wdus": "What Did You Say",
    "wdut": "what do you think?",
    "wdutom": "what do you think of me",
    "wduw": "what do you want",
    "wduwta": "what do you wanna talk about",
    "wduwtta": "what do you want to talk about",
    "wdwdn": "what do we do now",
    "wdwgw": "where did we go wrong",
    "wdydt": "why do you do that",
    "wdye": "What do you expect",
    "wdyl": "who do you like",
    "wdym": "what do you mean",
    "wdys": "What did you say",
    "wdyt": "what do you think",
    "wdytia": "who do you think i am?",
    "wdyw": "what do you want",
    "wdywd": "what do you want to do?",
    "wdywtd": "what do you want to do",
    "wdywtdt": "Why Do You Want To Do That?",
    "wdywtta": "what do you want to talk about",
    "webby": "webcam",
    "weg": "wicked evil grin",
    "welc": "welcome",
    "wen": "when",
    "werkz": "works",
    "wev": "Whatever",
    "weve": "what ever",
    "wevr": "whatever",
    "wfh": "Working From Home",
    "wfhw": "what's for homework",
    "wfm": "Works For Me",
    "wfyb": "whatever floats your boat",
    "wg": "wicked gril",
    "wgac": "who gives a crap",
    "wgaf": "Who gives a fuck",
    "wgas": "who gives a shit",
    "wgasa": "who gives a shit anyway",
    "wgo": "what's going on",
    "wgph2": "Want to go play Halo 2?",
    "wha": "what?",
    "whaddya": "what do you",
    "whaletail": "thong",
    "whatcha": "what are you",
    "whatev": "whatever",
    "whatevs": "whatever",
    "whats ^": "whats up",
    "what^": "what's up?",
    "whenevs": "whenever",
    "whevah": "where ever",
    "whever": "whatever",
    "whf": "Wanna have fun?",
    "whit": "with",
    "whodi": "friend",
    "whr": "where",
    "whs": "wanna have sex",
    "wht": "What",
    "whteva": "what ever",
    "whteve": "whatever",
    "whtever": "whatever",
    "whtevr": "whatever",
    "whtvr": "whatever",
    "wht^": "what up",
    "whubu2": "what have you been up to",
    "whubut": "what have you been up to",
    "whut": "what",
    "whyb": "where have you been",
    "whyd": "What Have You Done",
    "wid": "with",
    "widout": "without",
    "wieu2": "What Is Everyone Up To",
    "wif": "With",
    "wiid": "what if i did",
    "wilco": "will comply",
    "winnar": "winner",
    "wio": "without",
    "wip": "Work In progress",
    "wit": "with",
    "witcha": "with you",
    "witfp": "What is the fucking point",
    "witu": "with you",
    "witw": "what in the world",
    "witwct": "What is the world coming too",
    "witwu": "who is there with you",
    "witwwyt": "what in the world were you thinking",
    "wiu": "What is up?",
    "wiuwu": "what is up with you",
    "wiv": "with",
    "wiw": "wife is watching",
    "wiwhu": "wish I was holding you",
    "wiwt": "wish i was there ",
    "wiyp": "what is your problem",
    "wjwd": "What Jesus Would Do",
    "wk": "week",
    "wkd": "wicked",
    "wkend": "weekend",
    "wl": "will",
    "wlc": "welcome",
    "wlcb": "welcome back",
    "wlcm": "welcome",
    "wld": "would",
    "wlkd": "walked",
    "wlos": "wife looking over Shoulder",
    "wltm": "would like to meet",
    "wmao": "working my ass off",
    "wmd": "Weapons Of Mass Destruction",
    "wmgl": "wish me good luck",
    "wml": "Wish Me Luck",
    "wmyb": "What Makes You Beautiful",
    "wn": "when",
    "wna": "want to",
    "wnkr": "wanker",
    "wnrn": "why not right now",
    "wnt": "want",
    "wntd": "what not to do",
    "woa": "word of advice",
    "woc": "welcome on cam",
    "wochit": "watch it",
    "woe": "what on earth",
    "woft": "Waste of fucking time",
    "wogge": "what on god's green earth?",
    "wogs": "waste of good sperm",
    "wolo": "we only live once",
    "wombat": "waste of money, brains, and time",
    "woot": "woohoo",
    "wot": "what",
    "wotevs": "whatever",
    "wotv": "What's on Television?",
    "wotw": "word of the week",
    "woum": "what's on your mind",
    "wowzers": "wow",
    "woz": "was",
    "wp": "wrong person",
    "wpe": "worst president ever (Bush)",
    "wrd": "word",
    "wrdo": "weirdo",
    "wrgad": "who really gives a dicn",
    "wrgaf": "Who really gives a fuck?",
    "wrk": "work",
    "wrm": "which reminds me",
    "wrng": "wrong",
    "wrt": "with regard to",
    "wrtg": "writing",
    "wrthls": "Worthless",
    "wru": "where are you",
    "wrud": "what are you doing",
    "wruf": "where are you from",
    "wruu2": "what are you up to",
    "wsb": "wanna cyber?",
    "wsf": "we should fuck",
    "wshtf": "when shit hits the fan",
    "wsi": "why should I",
    "wsibt": "when should i be there",
    "wsidi": "Why Should I Do It",
    "wsop": "world series of poker",
    "wswta": "What shall we talk about?",
    "wtb": "Want to buy",
    "wtbd": "what's the big deal",
    "wtbh": "What the bloody hell",
    "wtc": "what the crap",
    "wtcf": "what the crazy fuck",
    "wtd": "what the deuce",
    "wtf": "what the fuck",
    "wtfaud": "what the fuck are you doing?",
    "wtfay": "who the fuck are you",
    "wtfayd": "what the fuck are you doing",
    "wtfayt": "why the fuck are you talking",
    "wtfayta": "What the fuck are you talking about?",
    "wtfb": "what the fuck bitch",
    "wtfbs": "What the fuck bull shit",
    "wtfc": "Who The fuck Cares",
    "wtfdik": "what the fuck do i know",
    "wtfdum": "what the fuck do you mean",
    "wtfduw": "What the fuck do you want?",
    "wtfdyw": "what the fuck do you want",
    "wtfe": "What The fuck Ever",
    "wtfever": "what the fuck ever",
    "wtfg": "What the fucking god",
    "wtfh": "what the fucking hell",
    "wtfhb": "what the fucking hell bitch",
    "wtfhwt": "what the fucking hell was that",
    "wtfigo": "what the fuck is going on",
    "wtfigoh": "what the fuck is going on here",
    "wtfit": "what the fuck is that",
    "wtfits": "what the fuck is this shit",
    "wtfiu": "what the fuck is up",
    "wtfiup": "what the fuck is your problem",
    "wtfiuwy": "what the fuck is up with you",
    "wtfiwwu": "what the fuck is wrong with you",
    "wtfiwwy": "what the fuck is wrong with you",
    "wtfiyp": "what the fuck is your problem",
    "wtfm": "what the fuck, mate?",
    "wtfmf": "what the fuck mother fucker",
    "wtfo": "what the fuck over",
    "wtfru": "what the fuck are you",
    "wtfrud": "What the fuck are you doing?",
    "wtfrudng": "what the fuck are you doing",
    "wtfrudoin": "what the fuck are you doing",
    "wtfruo": "what the fuck are you on?",
    "wtfruttd": "what the fuck are you trying to do",
    "wtfs": "what the fucking shit?",
    "wtfuah": "what the fuck you asshole",
    "wtful": "What the fuck you loser",
    "wtfwjd": "what the fuck would jesus do",
    "wtfwt": "what the fuck was that",
    "wtfwtd": "what the fuck was that dude",
    "wtfwtf": "what the fuck was that for?",
    "wtfya": "what the fuck you asshole",
    "wtfyb": "what the fuck you bitch",
    "wtg": "way to go",
    "wtgds": "way to go dumb shit",
    "wtgp": "Want to go Private",
    "wth": "what the heck",
    "wtharud": "what the heck are you doing",
    "wthau": "who the hell are you",
    "wthauwf": "what the hell are you waiting for",
    "wthay": "who the hell are you",
    "wthayd": "what the heck are you doing",
    "wthaydwmgf": "what the hell are you doing with my girlfriend",
    "wthdydt": "why the hell did you do that",
    "wthhyb": "where the hell have you been?",
    "wthigo": "what the hell is going on",
    "wthiwwu": "What the hell is wrong with you",
    "wtho": "want to hang out?",
    "wthru": "Who the heck are you",
    "wthrud": "what the hell are you doing?",
    "wths": "want to have sex",
    "wthswm": "want to have sex with me",
    "wthwt": "what the hell was that?",
    "wthwut": "what the hell were you thinking",
    "wthyi": "what the hell you idiot",
    "wtii": "what time is it",
    "wtiiot": "What time is it over there?",
    "wtityb": "whatever, tell it to your blog",
    "wtly": "Welcome to last year",
    "wtmf": "what the mother fuck",
    "wtmfh": "what the mother fucking hell",
    "wtmi": "way too much information",
    "wtmtr": "what's the matter",
    "wtp": "where's the party",
    "wtrud": "what are you doing",
    "wts": "want to sell",
    "wtt": "want to trade",
    "wttp": "want to trade pictures?",
    "wtv": "Whatever",
    "wtva": "whatever",
    "wtvr": "whatever",
    "wtwm": "what time are we meeting?",
    "wtwr": "well that was random",
    "wu2kilu": "want you to know I love you",
    "wub": "love",
    "wubmgf": "Will You Be My Girlfriend?",
    "wubu2": "what you been up to",
    "wubut": "what you been up too",
    "wud": "would",
    "wudev": "Whatever",
    "wudn": "what you doing now",
    "wugowm": "will you go out with me",
    "wula": "what you looking at?",
    "wuld": "would",
    "wuny": "wait until next year",
    "wussup": "What is up?",
    "wut": "what",
    "wutb": "What are you talking about",
    "wutcha": "What are you",
    "wuteva": "whatever",
    "wutevr": "what ever",
    "wuts": "what is",
    "wutup": "What's Up",
    "wuu22m": "what you up to tomorrow",
    "wuut": "what you up to",
    "wuv": "love",
    "wuwh": "Wish you were here",
    "wuwt": "what's up with that",
    "wuwta": "what do you want to talk about",
    "wuwtab": "what do you want to talk about",
    "wuwtb": "what do you want to talk about",
    "wuwtta": "what you want to talk about",
    "wuwu": "what up with you",
    "wuz": "was",
    "wuza": "what's up",
    "wuzup": "what's up",
    "wwc": "who would care",
    "wwcnd": "What would Chuck Norris do",
    "wwdhd": "What would David Hasselhoff do",
    "wwe": "World Wrestling Entertainment",
    "wwgf": "when we gonna fuck",
    "wwhw": "when where how why",
    "wwikt": "why would i know that",
    "wwjd": "what would jesus do?",
    "wwt": "what was that",
    "wwtf": "what was that for",
    "wwudtm": "what would you do to me",
    "wwut": "what were you thinking",
    "www": "world wide web",
    "wwwy": "what's wrong with you",
    "wwy": "where were you",
    "wwycm": "when will you call me",
    "wwyd": "what would you do?",
    "wwyd2m": "what would you do to me",
    "wwyt": "What were you thinking",
    "wy": "Why?",
    "wyas": "wow you are stupid",
    "wyatb": "wish you all the best",
    "wyauimg": "Why you all up in my grill?",
    "wybts": "were you born this sexy",
    "wyc": "will you come",
    "wycm": "Will You Call Me",
    "wyd": "what are you doing",
    "wyg": "will you go",
    "wygac": "when you get a chance",
    "wygam": "When you get a minute",
    "wygowm": "Will you go out with me",
    "wygwm": "will you go with me",
    "wyhi": "Would You Hit It?",
    "wyhswm": "would you have sex with me",
    "wyltk": "wouldn't you like to know",
    "wylym": "Watch Your Language Young Man",
    "wym": "What You Mean?",
    "wyn": "What's your name",
    "wyp": "what's your problem?",
    "wypsu": "will you please shut up",
    "wys": "wow you're stupid",
    "wysiayg": "what you see is all you get",
    "wysitwirl": "what you see is totally worthless in real life",
    "wysiwyg": "what you see is what you get",
    "wyw": "What You Want",
    "wywh": "wish you were here",
    "wywo": "while you were out",
    "w\e": "whatever",
    "x treme": "extreme",
    "xb36t": "Xbox 360",
    "xbf": "ex-boyfriend",
    "xbl": "xbox live",
    "xcept": "except",
    "xcpt": "except",
    "xd": "extreme droll",
    "xellent": "excellent",
    "xfer": "transfer",
    "xgf": "exgirlfriend",
    "xing": "crossing",
    "xit": "Exit",
    "xl": "extra large",
    "xlnt": "Excellent",
    "xmas": "christmas",
    "xmpl": "example",
    "xoac": "Christ on a crutch",
    "xor": "hacker",
    "xover": "crossover",
    "xox": "hugs and kisses",
    "xoxo": "hugs and kisses",
    "xp": "experience",
    "xpect": "expect",
    "xplaned": "explained",
    "xpt": "except",
    "xroads": "crossroads",
    "xs": "excess",
    "xtc": "ecstasy",
    "xtra": "extra",
    "xtreme": "extreme",
    "xyz": "examine your zipper",
    "xyzpdq": "Examine Your Zipper Pretty Darn Quick",
    "y": "why",
    "y w": "you're welcome",
    "y!a": "yahoo answers",
    "y'all": "you all",
    "y/n": "yes or no",
    "y/o": "Years Old",
    "y00": "you",
    "y2b": "Youtube",
    "y2k": "year 2000",
    "ya": "yeah",
    "yaaf": "you are a fuc",
    "yaafm": "You Are A fucking Moron",
    "yaagf": "you are a good friend",
    "yaai": "You are an idiot",
    "yaf": "you're a fuc",
    "yafi": "you're a fucking idiot",
    "yag": "you are gay",
    "yall": "you all",
    "yapa": "yet another pointless acronym",
    "yaqw": "You are quite welcome",
    "yarly": "yeah really",
    "yas": "you are stupid",
    "yasan": "You are such a nerd",
    "yasf": "you are so funny",
    "yasfg": "you are so fucking gay",
    "yasg": "you are so gay",
    "yasw": "you are so weird",
    "yatb": "you are the best",
    "yatwl": "you are the weakest link",
    "yaw": "you are welcome",
    "yayo": "cocaine",
    "ybbg": "Your Brother By Grace",
    "ybs": "you'll be sorry",
    "ybya": "you bet your ass",
    "ycliu": "You could look it up",
    "ycmtsu": "You Can't Make This shit Up",
    "ycntu": "Why Cant You?",
    "yctwuw": "you can think what you want",
    "ydpos": "you dumb piece of shit",
    "ydtm": "You're dead to me",
    "ydufc": "Why do fucking care?",
    "yduwtk": "why do you want to know",
    "ye": "yeah",
    "yea": "yeah",
    "yer": "you're",
    "yermom": "your mother",
    "yesh": "yes",
    "yew": "you",
    "yfb": "you fucking bitched",
    "yfg": "you're fucking gay",
    "yfi": "you fucking idiot",
    "ygg": "you go girl",
    "ygm": "You Got Mail",
    "ygp": "you got punked!",
    "ygpm": "you've got a private message",
    "ygrr": "you got rick rolled",
    "ygtbfkm": "you've got to be fucking kidding me",
    "ygtbk": "you've got to be kidding",
    "ygtbkm": "you got to be kidding me",
    "ygtbsm": "You've got to be shitting me",
    "ygtsr": "you got that shit right",
    "yh": "yeah",
    "yhbt": "you've been trolled",
    "yhew": "you",
    "yhf": "you have failed",
    "yhgtbsm": "You Have Got To Be Shitting Me",
    "yhl": "you have lost",
    "yhm": "You have mail",
    "yhpm": "you have a private messge",
    "yhtbt": "You Had To Be There",
    "yid": "yes, I do",
    "yim": "yahoo instant messenger",
    "yiwtgo": "Yes, I want to go private",
    "yk": "you kidding",
    "yki": "You know it",
    "ykisa": "Your knight in shining armor",
    "ykm": "You're killing me",
    "ykn": "you know nothing",
    "ykw": "You Know What",
    "ykwim": "you know what I mean",
    "ykwya": "you know who you are",
    "ykywywm": "you know you wish you were me",
    "ylb": "you little bitch",
    "ym": "your mom",
    "ymbkm": "you must be kidding me",
    "yme": "why me",
    "ymfp": "Your Most Favorite Person",
    "ymg2c": "your mom goes to college",
    "ymgtc": "Your Mom Goes To college",
    "ymiaw": "your mom is a whore",
    "ymislidi": "you make it sound like i did it",
    "ymmd": "You Made My Day",
    "ymmv": "your mileage may vary",
    "ymrasu": "Yes, My Retarded ass Signed Up",
    "yn": "why not",
    "yng": "young",
    "ynk": "you never know",
    "ynm": "yes, no, maybe",
    "ynt": "why not",
    "ynw": "you know what",
    "yo": "year old",
    "yo'": "your",
    "yodo": "you only die once",
    "yolo": "you only live once",
    "yolt": "you only live twice",
    "yomank": "you owe me a new keyboard",
    "yooh": "you",
    "yor": "your",
    "youngin": "young person",
    "yoy": "why oh why",
    "ypmf": "you pissed me off",
    "ypmo": "you piss me off",
    "ypom": "your place or mine",
    "yqw": "you're quite welcome",
    "yr": "year",
    "yrbk": "Yearbook",
    "yrms": "You Rock My Socks",
    "yrs": "years",
    "yrsaf": "You Are Such A Fool ",
    "yrsm": "you really scare me",
    "yrss": "you are so sexy",
    "yru": "why are you?",
    "yrubm": "why are you bugging me?",
    "yrusm": "Why are you so mean",
    "ys": "you suck",
    "ysa": "You Suck ass",
    "ysal": "you suck at life",
    "ysati": "you suck at the internet",
    "ysf": "you stupid fuck",
    "ysic": "why should I care",
    "ysitm": "your shirt is too small",
    "ysm": "you scare me",
    "ysoab": "You son of a bitch",
    "yss": "you stupid shit",
    "yswnt": "why sleep when not tired?",
    "yt": "You there?",
    "ytd": "year to date",
    "ytf": "why the fuck",
    "ytfwudt": "why the fuck would you do that?",
    "ythwudt": "Why the hell would you do that",
    "ytis": "You think I'm special?",
    "ytm": "you tell me",
    "ytmnd": "You're the man now, dog!",
    "yty": "why thank you",
    "yu": "You",
    "yua": "you ugly ass",
    "yuo": "you",
    "yup": "yes",
    "yur": "your",
    "yust": "why you say that",
    "yvfw": "you're very fucking welcome",
    "yvw": "you're very welcome",
    "yw": "you're welcome",
    "ywapom": "you want a piece of me?",
    "ywia": "You're welcome in advance",
    "ywic": "why would i care",
    "yws": "you want sex",
    "ywsyls": "you win some you lose some",
    "ywud": "yo whats up dude",
    "ywvm": "you're welcome very much",
    "ywywm": "you wish you were me",
    "yysw": "yeah, yeah, sure, whatever",
    "z'omg": "Oh my God",
    "z0mg": "oh my god",
    "zex": "sex",
    "zh": "Zero Hour",
    "zig": "cigarette",
    "zomfg": "oh my fucking god",
    "zomg": "Oh my God",
    "zomgzorrz": "oh my god",
    "zoot": "woohoo",
    "zot": "Zero Tolerance",
    "zt": "zoo tycoon",
    "zup": "what's up?"
}

# remove one char entries
slangdict = {k: v for k, v in slangdict.items() if len(k.strip(" ")) > 1}

pickle.dump(slangdict, open("slangdict.pickle", "wb"))
